/*
 * File: F28M35H52C1_ClkCfgRegs.h
 */

#ifndef __F28M35H52C1_CLKCFGREGS_H__
#define __F28M35H52C1_CLKCFGREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

#define C28_CLKIN_PLLCLK_DIV_1                      ( 0x00000000 )

#define C28_CLKIN_PLLCLK_DIV_2                      ( 0x00000001 )

#define C28_CLKIN_PLLCLK_DIV_4                      ( 0x00000002 )

#define C28_CLKIN_PLLCLK_DIV_8                      ( 0x00000003 )

#define M3SSDIVSEL_PLLCLK_DIV_1                     ( 0x00000000 )

#define M3SSDIVSEL_PLLCLK_DIV_2                     ( 0x00000001 )

#define M3SSDIVSEL_PLLCLK_DIV_4                     ( 0x00000002 )

/*
 * System PLL Configuration (SYSPLLCTL) Register (Page 222 TRM)
 * MWRALLOW
 */
struct SYSPLLCTL_BITS {
    uint32_t SPLLEN     :       1;

    uint32_t SPLLCLKEN  :       1;

    uint32_t RSVRD      :       30;
};

union SYSPLLCTL_REG {
    uint32_t    all;

    struct      SYSPLLCTL_BITS bit;
};


/*
 * System PLL Multiplier (SYSPLLMULT) Register (Page 225 TRM)
 * MWRALLOW
 */
struct SYSPLLMULT_BITS {
    uint32_t SPLLIMULT  :       7;

    uint32_t RSVRD1     :       1;

    uint32_t SPLLFMULT  :       2;

    uint32_t RSVRD2     :       22;
};

union SYSPLLMULT_REG {
    uint32_t    all;

    struct      SYSPLLMULT_BITS bit;
};


/*
 * System PLL Lock Status (SYSPLLSTS) Register (Page 227 TRM)
 */
struct SYSPLLSTS_BITS {
    uint32_t SYSPLLLOCKS    :   1;

    uint32_t SPLLSLIPS      :   1;

    uint32_t RSVRD          :  30;
};

union SYSPLLSTS_REG {
    uint32_t    all;

    struct      SYSPLLSTS_BITS bit;
};


/*
 * System Clock Divider (SYSDIVSEL) Register (Page 226 TRM)
 * MWRALLOW
 */
struct SYSDIVSEL_BITS {
    uint32_t SYSDIVSEL      :   2;

    uint32_t RSVRD          :  30;
};

union SYSDIVSEL_REG {
    uint32_t    all;

    struct      SYSDIVSEL_BITS bit;
};


/*
 * Master Subsystem Clock Divider (M3SSDIVSEL) Register (Page 227 TRM)
 * MWRALLOW
 */
struct M3SSDIVSEL_BITS {
    uint32_t M3SSDIVSEL     :   2;

    uint32_t RSVRD          :  30;
};

union M3SSDIVSEL_REG {
    uint32_t    all;

    struct      M3SSDIVSEL_BITS bit;
};


/*
 * USB PLL Configuration (UPLLCTL) Register (Page 228 TRM)
 * MWRALLOW
 */
struct UPLLCTL_BITS {
    uint32_t UPLLCLKSRCSEL  :   1;

    uint32_t UPLLEN         :   1;

    uint32_t UPLLCLKEN      :   1;

    uint32_t RSVRD          :  29;
};

union UPLLCTL_REG {
    uint32_t    all;

    struct      UPLLCTL_BITS bit;
};


/*
 * USB PLL Multiplier (UPLLMULT) Register (Page 229 TRM)
 * MWRALLOW
 */
struct UPLLMULT_BITS {
    uint32_t UPLLIMULT      :   6;

    uint32_t RSVRD1         :   2;

    uint32_t UPLLFMULT      :   2;

    uint32_t RSVRD2         :  22;
};

union UPLLMULT_REG {
    uint32_t    all;

    struct      UPLLMULT_BITS bit;
};


/*
 * USB PLL Lock Status (UPLLSTS) Register (Page 229 TRM)
 */
struct UPLLSTS_BITS {
    uint32_t UPLLLOCKS      :   1;

    uint32_t UPLLSLIPS      :   1;

    uint32_t RSVRD          :  30;
};

union UPLLSTS_REG {
    uint32_t    all;

    struct      UPLLSTS_BITS bit;
};


/*
 * Missing Clock Status (MCLKSTS) Register (Page 224 TRM)
 */
struct MCLKSTS_BITS {
    uint32_t REFCLKCNT      :   8;

    uint32_t RSVRD1         :   8;

    uint32_t MCLKFLG        :   1;

    uint32_t RSVRD2         :   15;
};

union MCLKSTS_REG {
    uint32_t    all;

    struct      MCLKSTS_BITS bit;
};


/*
 * Missing Clock Force (MCLKFRCCLR) Register (Page 224 TRM)
 * MWRALLOW
 */
struct MCLKFRCCLR_BITS {
    uint32_t REFCLKOFF      :   1;

    uint32_t RSVRD1         :   15;

    uint32_t MCLKCLR        :   1;

    uint32_t RSVRD2         :   15;
};

union MCLKFRCCLR_REG {
    uint32_t    all;

    struct      MCLKFRCCLR_BITS bit;
};


/*
 * Missing Clock Enable (MCLKEN) Register (Page 225 TRM)
 * MWRALLOW
 */
struct MCLKEN_BITS {
    uint32_t RSVRD1         :   8;

    uint32_t MCLKNMIEN      :   1;

    uint32_t RSVRD2         :   23;
};

union MCLKEN_REG {
    uint32_t    all;

    struct      MCLKEN_BITS bit;
};


/*
 * Missing Clock Reference Limit (MCLKLIMIT) Register (Page 225 TRM)
 * MWRALLOW
 */
struct MCLKLIMIT_BITS {
    uint32_t REFCLKLOLIMIT  :   8;

    uint32_t REFCLKHILIMIT  :   8;

    uint32_t RSVRD          :   16;
};

union MCLKLIMIT_REG {
    uint32_t    all;

    struct      MCLKLIMIT_BITS bit;
};


typedef enum
{
    XPLL_OFF_CLOCKOUT = 0,

    XPLL_C28_SYSCLK_DIV4_CLKOUT,

    XPLL_M3_SSCLK_DIV24_CLKOUT,

    XPLL_PLLSYSCLK_DIV4_CLKOUT,

} XPLLCLKOUT_ENUM;
/*
 * XPLL CLKOUT Control (XPLLCLKCFG) Register (Page 227 TRM)
 * MWRALLOW
 */
struct XPLLCLKCFG_BITS {
    uint32_t XPLLCLKOUTDIV  :   2;

    uint32_t RSVRD          :   30;
};

union XPLLCLKCFG_REG {
    uint32_t    all;

    struct      XPLLCLKCFG_BITS bit;
};


/*
 * Control Subsystem Clock Disable (CCLKOFF) Register (Page 222 TRM)
 * MWRALLOW
 */
struct CCLKOFF_BITS {
    uint32_t C28CLKINDIS    :   1;

    uint32_t RSVRD          :   31;
};

union CCLKOFF_REG {
    uint32_t    all;

    struct      CCLKOFF_BITS bit;
};


/*
 * Bit Clock Source Selection for CAN0 (CAN0BCLKSEL) Register (Page 230 TRM)
 * MWRALLOW
 */
struct CAN0BCLKSEL_BITS {
    uint32_t BCLKSEL        :   2;

    uint32_t RSVRD          :   30;
};

union CAN0BCLKSEL_REG {
    uint32_t    all;

    struct      CAN0BCLKSEL_BITS bit;
};


/*
 * Bit Clock Source Selection for CAN1 (CAN1BCLKSEL) Register (Page 230 TRM)
 * MWRALLOW
 */
struct CAN1BCLKSEL_BITS {
    uint32_t BCLKSEL        :   2;

    uint32_t RSVRD          :   30;
};

union CAN1BCLKSEL_REG {
    uint32_t    all;

    struct      CAN1BCLKSEL_BITS bit;
};


struct SYS_CLK_CFG_REGS {
    union SYSPLLCTL_REG         SYSPLLCTL;

    union SYSPLLMULT_REG        SYSPLLMULT;

    union SYSPLLSTS_REG         SYSPLLSTS;

    union SYSDIVSEL_REG         SYSDIVSEL;

    union M3SSDIVSEL_REG        M3SSDIVSEL;

    uint32_t RSVRD1[ ( 0x20 - 0x14 ) >> 2 ];

    union UPLLCTL_REG           UPLLCTL;

    union UPLLMULT_REG          UPLLMULT;

    union UPLLSTS_REG           UPLLSTS;

    uint32_t RSVRD2[ ( 0x30 - 0x2C ) >> 2 ];

    union MCLKSTS_REG           MCLKSTS;

    uint32_t RSVRD3[ ( 0x38 - 0x34 ) >> 2 ];

    union MCLKFRCCLR_REG        MCLKFRCCLR;

    union MCLKEN_REG            MCLKEN;

    union MCLKLIMIT_REG         MCLKLIMIT;

    uint32_t RSVRD4[ ( 0x50 - 0x44 ) >> 2 ];

    union XPLLCLKCFG_REG        XPLLCLKCFG;

    uint32_t RSVRD5[ ( 0x60 - 0x54 ) >> 2 ];

    union CCLKOFF_REG           CCLKOFF;

    uint32_t RSVRD6[ ( 0x70 - 0x64 ) >> 2 ];

    union CAN0BCLKSEL_REG       CAN0BCLKSEL;

    union CAN1BCLKSEL_REG       CAN1BCLKSEL;
};

extern volatile struct SYS_CLK_CFG_REGS ClkCfgRegs;

#ifdef __cplusplus
}
#endif

#endif /* __F28M35H52C1_CLKCFGREGS_H__ */
