/*
 * File: F28M35H52C1_FlashCtlRegs.h
 */

#ifndef __F28M35H52C1_FLASHCTLREGS_H__
#define __F28M35H52C1_FLASHCTLREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Flash Read Control Register (FRDCNTL) (Page 515 TRM)
 * MWRALLOW
 */
struct FRDCNTL_BITS
{
    uint32_t RSVRD1             :   8;

    uint32_t RWAIT              :   4;

    uint32_t RSVRD2             :   20;
};


union FRDCNTL_REG
{
    uint32_t    all;

    struct      FRDCNTL_BITS bit;
};


/*
 * Flash Read Margin Control Register (FSPRD) (Page 515 TRM)
 * MWRALLOW
 */
struct FSPRD_BITS
{
    uint32_t RM0                :   1;

    uint32_t RM1                :   1;

    uint32_t RSVRD              :   30;
};


union FSPRD_REG
{
    uint32_t    all;

    struct      FSPRD_BITS bit;
};


/*
 * Flash Bank Access Control Register (FBAC) (Page 516 TRM)
 * MWRALLOW
 */
struct FBAC_BITS
{
    uint32_t VREADST            :   8;

    uint32_t BAGP7_0            :   8;

    uint32_t RSVRD              :   16;
};


union FBAC_REG
{
    uint32_t    all;

    struct      FBAC_BITS bit;
};


/*
 * Flash Bank Access Control Register (FBAC) (Page 516 TRM)
 * MWRALLOW
 */
struct FBFALLBACK_BITS
{
    uint32_t BNKPWR             :   2;

    uint32_t RSVRD              :   30;
};


union FBFALLBACK_REG
{
    uint32_t    all;

    struct      FBFALLBACK_BITS bit;
};


/*
 * Flash Bank Pump Control Register 1 (FBPRDY) (Page 517 TRM)
 * MWRALLOW
 */
struct FBPRDY_BITS
{
    uint32_t BANKRDY            :   1;

    uint32_t RSVRD1             :   14;

    uint32_t PUMPRDY            :   1;

    uint32_t RSVRD2             :   16;
};


union FBPRDY_REG
{
    uint32_t    all;

    struct      FBPRDY_BITS bit;
};


/*
 * Flash Bank Pump Control Register 1 (FPAC1) (Page 517 TRM)
 * MWRALLOW
 */
struct FPAC1_BITS
{
    uint32_t PMPPWR             :   1;

    uint32_t RSVRD1             :   14;

    uint32_t PSLEEP             :   11;

    uint32_t RSVRD2             :   6;
};


union FPAC1_REG
{
    uint32_t    all;

    struct      FPAC1_BITS bit;
};


/*
 * Flash Bank Pump Control Register 2 (FPAC2) (Page 518 TRM)
 * MWRALLOW
 */
struct FPAC2_BITS
{
    uint32_t PAGP               :   16;

    uint32_t RSVRD              :   16;
};


union FPAC2_REG
{
    uint32_t    all;

    struct      FPAC2_BITS bit;
};


/*
 * Flash Module Access Control Register (FMAC) (Page 518 TRM)
 * MWRALLOW
 */
struct FMAC_BITS
{
    uint32_t BANK               :   2;

    uint32_t RSVRD              :   30;
};


union FMAC_REG
{
    uint32_t    all;

    struct      FMAC_BITS bit;
};



/*
 * SECZONEREQUEST(SEM) Register (Page 519 TRM)
 * MWRALLOW
 */
struct SECZONEREQUEST_BITS
{
    uint32_t SEM                :   2;

    uint32_t RSVRD              :   2;

    uint32_t KEY                :   28;
};


union SECZONEREQUEST_REG
{
    uint32_t    all;

    struct      SECZONEREQUEST_BITS bit;
};


/*
 * Flash Read Interface Control Register (FRD_INTF_CTRL) Register (Page 520 TRM)
 * MWRALLOW
 */
struct FRD_INTF_CTRL_BITS
{
    uint32_t PROG_CACHE_EN      :   1;

    uint32_t DATA_CATCHE_EN     :   1;

    uint32_t RSVRD              :   30;
};


union FRD_INTF_CTRL_REG
{
    uint32_t    all;

    struct      FRD_INTF_CTRL_BITS bit;
};


struct FLASH_CTL_REGS
{
    union FRDCNTL_REG               FRDCNTL;

    union FSPRD_REG                 FSPRD;

    uint32_t RSVRD1[13];

    union FBAC_REG                  FBAC;

    union FBFALLBACK_REG            FBFALLBACK;

    union FBPRDY_REG                FBPRDY;

    union FPAC1_REG                 FPAC1;

    union FPAC2_REG                 FPAC2;

    union FMAC_REG                  FMAC;

    uint32_t RSVRD2[67];

    union SECZONEREQUEST_REG        SECZONEREQUEST;

    uint32_t RSVRD3[103];

    union FRD_INTF_CTRL_REG         FRD_INTF_CTRL;
};

extern volatile struct FLASH_CTL_REGS FlashCtlRegs;

#ifdef __cplusplus
}
#endif

#endif /* __F28M35H52C1_FLASHCTLREGS_H__ */
