/*
 * File: F28M35H52C1_FlashECCErrorLogRegs.h
 */

#ifndef __FLASHECCERRORLOGREGS_H__
#define __FLASHECCERRORLOGREGS_H__

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ECC Enable Register (ECC_Enable) (Page 521 TRM)
 * MWRALLOW
 */
struct ECC_ENABLE_BITS
{
    uint32_t ENABLE             :   4; //ECC enable. A value of 0xA would enable ECC. Any other value would disable ECC.

    uint32_t RSVRD              :   28;
};


union ECC_ENABLE_REG
{
    uint32_t    all;

    struct      ECC_ENABLE_BITS bit;
};


/*
 * Single Error Address Register (SINGLE_ERR_ADDR) (Page 521 TRM)
 * MWRALLOW
 */
struct SINGLE_ERR_ADDR_BITS
{
    uint32_t ERR_ADDR           :   32;
};


union SINGLE_ERR_ADDR_REG
{
    uint32_t    all;

    struct      SINGLE_ERR_ADDR_BITS bit;
};


/*
 * Uncorrectable Error Address Register (UNC_ERR_ADDR) (Page 521 TRM)
 * MWRALLOW
 */
struct UNC_ERR_ADDR_BITS
{
    uint32_t UNC_ERR_ADDR       :   32;
};


union UNC_ERR_ADDR_REG
{
    uint32_t    all;

    struct      UNC_ERR_ADDR_BITS bit;
};


/*
 * Error Status Register (ERR_STATUS) (Page 522 TRM)
 * MWRALLOW
 */
struct ERR_STATUS_BITS
{
    uint32_t FAIL_0             :   1;

    uint32_t FAIL_1             :   1;

    uint32_t UNC_ERR            :   1;

    uint32_t RSVRD              :   29;
};


union ERR_STATUS_REG
{
    uint32_t    all;

    struct      ERR_STATUS_BITS bit;
};


/*
 * Error Position Register (ERR_POS) (Page 522 TRM)
 * MWRALLOW
 */
struct ERR_POS_BITS
{
    uint32_t ERR_POS            :   6;

    uint32_t ECC_L_OR_H         :   1;

    uint32_t RSVRD1             :   4;

    uint32_t ERR_TYPE           :   1;

    uint32_t RSVRD2             :   20;
};


union ERR_POS_REG
{
    uint32_t    all;

    struct      ERR_POS_BITS bit;
};


/*
 * Error Status Clear Register (ERR_STATUS_CLR) (Page 523 TRM)
 * MWRALLOW
 */
struct ERR_STATUS_CLR_BITS
{
    uint32_t FAIL_0_CLR         :   1;

    uint32_t FAIL_1_CLR         :   1;

    uint32_t UNC_ERR_CLR        :   1;

    uint32_t RSVRD2             :   29;
};


union ERR_STATUS_CLR_REG
{
    uint32_t    all;

    struct      ERR_STATUS_CLR_BITS bit;
};


/*
 * Error Counter Register (ERR_CNT) (Page 523 TRM)
 * MWRALLOW
 */
struct ERR_CNT_BITS
{
    uint32_t ERR_CNT            :   16;

    uint32_t RSVRD              :   16;
};


union ERR_CNT_REG
{
    uint32_t    all;

    struct      ERR_CNT_BITS bit;
};


/*
 * Error Threshold Register (ERR_THRESHOLD) (Page 524 TRM)
 * MWRALLOW
 */
struct ERR_THRESHOLD_BITS
{
    uint32_t THRESHOLD          :   16;

    uint32_t RSVRD              :   16;
};


union ERR_THRESHOLD_REG
{
    uint32_t    all;

    struct      ERR_THRESHOLD_BITS bit;
};


/*
 * Error Interrupt Flag Register (ERR_INTFLG) (Page 524 TRM)
 * MWRALLOW
 */
struct ERR_INTFLG_BITS
{
    uint32_t SINGLE_ERR_INT_FLG :   1;

    uint32_t UNC_ERR_INT_FLG    :   1;

    uint32_t RSVRD              :   30;
};


union ERR_INTFLG_REG
{
    uint32_t    all;

    struct      ERR_INTFLG_BITS bit;
};


/*
 * Error Interrupt Flag Clear Register (ERR_INTCLR) (Page 525 TRM)
 * MWRALLOW
 */
struct ERR_INTCLR_BITS
{
    uint32_t SINGLE_ERR_INT_CLR :   1;

    uint32_t UNC_ERR_INT_CLR    :   1;

    uint32_t RSVRD              :   30;
};


union ERR_INTCLR_REG
{
    uint32_t    all;

    struct      ERR_INTCLR_BITS bit;
};


/*
 * Data High Test Register (FDATAH_TEST) (Page 525 TRM)
 * MWRALLOW
 */
struct FDATAH_TEST_BITS
{
    uint32_t FDATAH             :   32;
};


union FDATAH_TEST_REG
{
    uint32_t    all;

    struct      FDATAH_TEST_BITS bit;
};


/*
 * Data Low Test Register (FDATAL_TEST) (Page 525 TRM)
 * MWRALLOW
 */
struct FDATAL_TEST_BITS
{
    uint32_t FDATAL             :   32;
};


union FDATAL_TEST_REG
{
    uint32_t    all;

    struct      FDATAL_TEST_BITS bit;
};


/*
 * ECC Test Address Register (FADDR_TEST) (Page 526 TRM)
 * MWRALLOW
 */
struct FADDR_TEST_BITS
{
    uint32_t ADDR               :   19;

    uint32_t RSVRD              :   13;
};


union FADDR_TEST_REG
{
    uint32_t    all;

    struct      FADDR_TEST_BITS bit;
};


/*
 * ECC Test Register (FECC_TEST) (Page 526 TRM)
 * MWRALLOW
 */
struct FECC_TEST_BITS
{
    uint32_t ECC                :   8;

    uint32_t RSVRD              :   24;
};


union FECC_TEST_REG
{
    uint32_t    all;

    struct      FECC_TEST_BITS bit;
};


/*
 * ECC Control Register (FECC_CTRL) (Page 526 TRM)
 * MWRALLOW
 */
struct FECC_CTRL_BITS
{
    uint32_t ECC_TEST_EN        :   1;

    uint32_t ECC_SELECT         :   1;

    uint32_t RSVRD              :   30;
};


union FECC_CTRL_REG
{
    uint32_t    all;

    struct      FECC_CTRL_BITS bit;
};


/*
 * Test Data Out High Register (FECC_FOUTH_TEST) (Page 526 TRM)
 * MWRALLOW
 */
struct FECC_FOUTH_TEST_BITS
{
    uint32_t DATAOUTH           :   32;
};


union FECC_FOUTH_TEST_REG
{
    uint32_t    all;

    struct      FECC_FOUTH_TEST_BITS bit;
};


/*
 * Test Data Out Low Register (FECC_FOUTL_TEST) (Page 527 TRM)
 * MWRALLOW
 */
struct FECC_FOUTL_TEST_BITS
{
    uint32_t DATAOUTL           :   32;
};


union FECC_FOUTL_TEST_REG
{
    uint32_t    all;

    struct      FECC_FOUTL_TEST_BITS bit;
};


/*
 * ECC Status Register (FECC_STATUS) (Page 527 TRM)
 * MWRALLOW
 */
struct FECC_STATUS_BITS
{
    uint32_t RSINGLE_ERR        :   1;

    uint32_t UNC_ERR            :   1;

    uint32_t ERR_POS            :   6;

    uint32_t CHK_ERR            :   1;

    uint32_t RSVRD              :   23;
};


union FECC_STATUS_REG
{
    uint32_t    all;

    struct      FECC_STATUS_BITS bit;
};


/*
 * Flash ECC/Error Log Registers (Page 512 TRM)
 */
struct FLASH_ECC_ERROR_LOG_REGS
{
    union ECC_ENABLE_REG                ECC_ENABLE;

    union SINGLE_ERR_ADDR_REG           SINGLE_ERR_ADDR;

    union UNC_ERR_ADDR_REG              UNC_ERR_ADDR;

    union ERR_STATUS_REG                ERR_STATUS;

    union ERR_POS_REG                   ERR_POS;

    union ERR_STATUS_CLR_REG            ERR_STATUS_CLR;

    union ERR_CNT_REG                   ERR_CNT;

    union ERR_THRESHOLD_REG             ERR_THRESHOLD;

    union ERR_INTFLG_REG                ERR_INTFLG;

    union ERR_INTCLR_REG                ERR_INTCLR;

    union FDATAH_TEST_REG               FDATAH_TEST;

    union FDATAL_TEST_REG               FDATAL_TEST;

    union FADDR_TEST_REG                FADDR_TEST;

    union FECC_TEST_REG                 FECC_TEST;

    union FECC_CTRL_REG                 FECC_CTRL;

    union FECC_FOUTH_TEST_REG           FECC_FOUTH_TEST;

    union FECC_FOUTL_TEST_REG           FECC_FOUTL_TEST;

    union FECC_STATUS_REG               FECC_STATUS;
};

extern volatile struct FLASH_ECC_ERROR_LOG_REGS FlashECCErrorLogRegs;

#ifdef __cplusplus
}
#endif

#endif /* __FLASHECCERRORLOGREGS_H__ */
