/*
 * File: F28M35H52C1_GPIORegs.h
 */

#ifndef __GPIOREGS_H__
#define __GPIOREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

#define GPIO_PIN_0                ( 0x00000001 )    // GPIO pin 0
#define GPIO_PIN_1                ( 0x00000002 )    // GPIO pin 1
#define GPIO_PIN_2                ( 0x00000004 )    // GPIO pin 2
#define GPIO_PIN_3                ( 0x00000008 )    // GPIO pin 3
#define GPIO_PIN_4                ( 0x00000010 )    // GPIO pin 4
#define GPIO_PIN_5                ( 0x00000020 )    // GPIO pin 5
#define GPIO_PIN_6                ( 0x00000040 )    // GPIO pin 6
#define GPIO_PIN_7                ( 0x00000080 )    // GPIO pin 7


/*
 * GPIO Data (GPIODATA) Register,(Page 350 TRM)
 */
struct GPIODATA_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIODATA_REG {
    uint32_t    all;

    struct      GPIODATA_BITS bit;
};


typedef enum
{
    GPIO_INPUT_DIR = 0,

    GPIO_OUTPUT_DIR,

} GPIO_DIR_ENUM;
/*
 * GPIO Direction (GPIODIR) Register,(Page 351 TRM)
 */
struct GPIODIR_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIODIR_REG {
    uint32_t    all;

    struct      GPIODIR_BITS bit;
};


typedef enum
{
    GPIO_EDGE_IS = 0,

    GPIO_LEVEL_IS,

} GPIO_INTERRUPT_SENSE_ENUM;

/*
 * GPIO Interrupt Sense (GPIOIS) Register, (Page 351 TRM)
 */
struct GPIOIS_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOIS_REG {
    uint32_t    all;

    struct      GPIOIS_BITS bit;
};


typedef enum
{
    GPIO_SINGLE_IBE = 0,

    GPIO_BOTH_IBE,

} GPIO_INTERRUPT_BOTH_EDGES_ENUM;

/*
 * GPIO Interrupt Both Edges (GPIOIBE) Register, (Page 352 TRM)
 */
struct GPIOIBE_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOIBE_REG {
    uint32_t    all;

    struct      GPIOIBE_BITS bit;
};



typedef enum
{
    GPIO_FALLING_OR_LOW_LEVEL_IEV = 0,

    GPIO_RISING_OR_HIGH_LEVEL_IEV,

} GPIO_INTERRUPT_EVENT_ENUM;

/*
 * GPIO Interrupt Event (GPIOIEV) Register, (Page 352 TRM)
 */
struct GPIOIEV_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOIEV_REG {
    uint32_t    all;

    struct      GPIOIEV_BITS bit;
};



typedef enum
{
    GPIO_INTERRUPT_DISABLED = 0,

    GPIO_INTERRUPT_ENABLED,

} GPIO_INTERRUPT_MASK_ENUM;

/*
 * GPIO Interrupt Mask (GPIOIM) Register, (Page 353 TRM)
 */
struct GPIOIM_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOIM_REG {
    uint32_t    all;

    struct      GPIOIM_BITS bit;
};



/*
 * GPIO Raw Interrupt Status (GPIORIS) Register, (Page 353 TRM)
 */
struct GPIORIS_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIORIS_REG {
    uint32_t    all;

    struct      GPIORIS_BITS bit;
};



/*
 * GPIO Masked Interrupt Status (GPIOMIS) Register, (Page 353 TRM)
 */
struct GPIOMIS_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOMIS_REG {
    uint32_t    all;

    struct      GPIOMIS_BITS bit;
};



/*
 * GPIO Interrupt Clear (GPIOICR) Register, (Page 354 TRM)
 */
struct GPIOICR_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOICR_REG {
    uint32_t    all;

    struct      GPIOICR_BITS bit;
};


/*
 * Page 346 TRM
 */
#define AFSEL_DIGITAL_IO                    ( 0 )
#define AFSEL_OD_O                          ( 0 )
#define AFSEL_OD_IO_I2C                     ( 1 )
#define AFSEL_DIGITAL_I_TIMER_CCP           ( 1 )
#define AFSEL_DIGITAL_O_TIMER_PWM           ( 1 )
#define AFSEL_DIGITAL_IO_SSI                ( 1 )
#define AFSEL_DIGITAL_IO_UART               ( 1 )
/*
 * GPIO Alternate Function Select (GPIOAFSEL) Register, (Page 355 TRM)
 */
struct GPIOAFSEL_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOAFSEL_REG {
    uint32_t    all;

    struct      GPIOAFSEL_BITS bit;
};



/*
 * GPIO Open Drain Select (GPIOODR) Register, (Page 356 TRM)
 */
struct GPIOODR_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOODR_REG {
    uint32_t    all;

    struct      GPIOODR_BITS bit;
};



/*
 * GPIO Pull-Up Select (GPIOPUR) Register, (Page 356 TRM)
 */
struct GPIOPUR_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIOPUR_REG {
    uint32_t    all;

    struct      GPIOPUR_BITS bit;
};



typedef enum
{
    GPIO_DIGITAL_FUNC_DISABLED = 0,

    GPIO_DIGITAL_FUNC_ENABLED,

} GPIO_DIGEN_ENUM;

/*
 * GPIO Digital Enable (GPIODEN) Register, (Page 357 TRM)
 */
struct GPIODEN_BITS {
    uint32_t PIN0       :       1;

    uint32_t PIN1       :       1;

    uint32_t PIN2       :       1;

    uint32_t PIN3       :       1;

    uint32_t PIN4       :       1;

    uint32_t PIN5       :       1;

    uint32_t PIN6       :       1;

    uint32_t PIN7       :       1;

    uint32_t RSVRD      :       24;
};

union GPIODEN_REG {
    uint32_t    all;

    struct      GPIODEN_BITS bit;
};



/*
 * GPIO Lock (GPIOLOCK) Register, (Page 358 TRM)
 */
struct GPIOLOCK_BITS {
    uint32_t LOCK       :       32;
};

union GPIOLOCK_REG {
    uint32_t    all;

    struct      GPIOLOCK_BITS bit;
};



/*
 * GPIO Commit (GPIOCR) Register, (Page 358 TRM)
 */
struct GPIOCR_BITS {
    uint32_t CR         :       8;

    uint32_t RSVRD      :       24;
};

union GPIOCR_REG {
    uint32_t    all;

    struct      GPIOCR_BITS bit;
};



/*
 * GPIO Analog Mode Select (GPIOAMSEL) Register, (Page 359 TRM)
 */
struct GPIOAMSEL_BITS {
    uint32_t RSVRD1     :       4;

    uint32_t GPIOAMSEL  :       4;

    uint32_t RSVRD2     :       24;
};

union GPIOAMSEL_REG {
    uint32_t    all;

    struct      GPIOAMSEL_BITS bit;
};



/*
 * GPIO Port Control (GPIOPCTL) Register, (Page 360 TRM)
 */
struct GPIOPCTL_BITS {
    uint32_t PMC0       :       4;

    uint32_t PMC1       :       4;

    uint32_t PMC2       :       4;

    uint32_t PMC3       :       4;

    uint32_t PMC4       :       4;

    uint32_t PMC5       :       4;

    uint32_t PMC6       :       4;

    uint32_t PMC7       :       4;
};

union GPIOPCTL_REG {
    uint32_t    all;

    struct      GPIOPCTL_BITS bit;
};



/*
 * GPIO Alternate Peripheral Select (GPIOAPSEL) Register, (Page 361 TRM)
 */
struct GPIOAPSEL_BITS {
    uint32_t APSEL0     :       1;

    uint32_t APSEL1     :       1;

    uint32_t APSEL2     :       1;

    uint32_t APSEL3     :       1;

    uint32_t APSEL4     :       1;

    uint32_t APSEL5     :       1;

    uint32_t APSEL6     :       1;

    uint32_t APSEL7     :       1;

    uint32_t RSVRD      :       24;
};

union GPIOAPSEL_REG {
    uint32_t    all;

    struct      GPIOAPSEL_BITS bit;
};


typedef enum
{
    M3_GPIO_CORE_SELECT = 0,

    C28_GPIO_CORE_SELECT,

} GPIO_CORE_SELECT_ENUM;
/*
 * GPIO Core Select (GPIOCSEL) Register, (Page 362 TRM)
 */
struct GPIOCSEL_BITS {
    uint32_t CSEL0      :       1;

    uint32_t CSEL1      :       1;

    uint32_t CSEL2      :       1;

    uint32_t CSEL3      :       1;

    uint32_t CSEL4      :       1;

    uint32_t CSEL5      :       1;

    uint32_t CSEL6      :       1;

    uint32_t CSEL7      :       1;

    uint32_t RSVRD      :       24;
};

union GPIOCSEL_REG {
    uint32_t    all;

    struct      GPIOCSEL_BITS bit;
};



struct GPIO_REGS
{
    union GPIODATA_REG          GPIODATA;

    uint32_t RSVRD1[ ( 0x400 - 0x004 ) >> 2 ];

    union GPIODIR_REG           GPIODIR;

    union GPIOIS_REG            GPIOIS;

    union GPIOIBE_REG           GPIOIBE;

    union GPIOIEV_REG           GPIOIEV;

    union GPIOIM_REG            GPIOIM;

    union GPIORIS_REG           GPIORIS;

    union GPIOMIS_REG           GPIOMIS;

    union GPIOICR_REG           GPIOICR;

    union GPIOAFSEL_REG         GPIOAFSEL;

    uint32_t RSVRD2[ ( 0x50C - 0x424 ) >> 2 ];

    union GPIOODR_REG           GPIOODR;

    union GPIOPUR_REG           GPIOPUR;

    uint32_t RSVRD3[ ( 0x51C - 0x514 ) >> 2 ];

    union GPIODEN_REG           GPIODEN;

    union GPIOLOCK_REG          GPIOLOCK;

    union GPIOCR_REG            GPIOCR;

    union GPIOAMSEL_REG         GPIOAMSEL;

    union GPIOPCTL_REG          GPIOPCTL;

    union GPIOAPSEL_REG         GPIOAPSEL;

    union GPIOCSEL_REG          GPIOCSEL;
};
/*
extern volatile struct GPIO_REGS GPIOARegs;

extern volatile struct GPIO_REGS GPIOBRegs;

extern volatile struct GPIO_REGS GPIOCRegs;

extern volatile struct GPIO_REGS GPIODRegs;

extern volatile struct GPIO_REGS GPIOERegs;

extern volatile struct GPIO_REGS GPIOFRegs;

extern volatile struct GPIO_REGS GPIOGRegs;

extern volatile struct GPIO_REGS GPIOHRegs;

extern volatile struct GPIO_REGS GPIOJRegs;

*/
#ifdef __cplusplus
}
#endif

#endif /* __GPIOREGS_H__ */
