/*
 * File: F28M35H52C1_GPTMRegs.h
 */

#ifndef __F28M35H52C1_GPTMREGS_H__
#define __F28M35H52C1_GPTMREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif


typedef enum
{
    GPTM_32BITS_CFG = 0,

    GPTM_32BITS_RTC_CFG,

    GPTM_16BITS_CFG = 4,

} GPTMFTG_ENUM;


typedef enum
{
    GPTM_ONE_SHOT_MODE = 1,

    GPTM_PERIODIC_MODE,

    GPTM_CAPTURE_MODE,

} GPTMTnMR_ENUM;


/*
 * GPTM Configuration (GPTMCFG) Register, (Page 310 TRM)
 */
struct GPTMCFG_BITS {
    uint32_t GPTMCFG    :       3;

    uint32_t RSVRD      :       29;
};

union GPTMCFG_REG {
    uint32_t    all;

    struct      GPTMCFG_BITS bit;
};


/*
 * GPTM Timer A Mode (GPTMTAMR) Register, (Page 311 TRM)
 */
struct GPTMTAMR_BITS {
    uint32_t TAMR       :       2;

    uint32_t TACMR      :       1;

    uint32_t TAAMS      :       1;

    uint32_t TACDIR     :       1;

    uint32_t TAMIE      :       1;

    uint32_t TAWOT      :       1;

    uint32_t TASNAPS    :       1;

    uint32_t RSVRD      :       24;
};

union GPTMTAMR_REG {
    uint32_t    all;

    struct      GPTMTAMR_BITS bit;
};


/*
 * GPTM Timer B Mode (GPTMTBMR) Register, (Page 312 TRM)
 */
struct GPTMTBMR_BITS {
    uint32_t TBMR       :       2;

    uint32_t TBCMR      :       1;

    uint32_t TBAMS      :       1;

    uint32_t TBCDIR     :       1;

    uint32_t TBMIE      :       1;

    uint32_t TBWOT      :       1;

    uint32_t TBSNAPS    :       1;

    uint32_t RSVRD      :       24;
};

union GPTMTBMR_REG {
    uint32_t    all;

    struct      GPTMTBMR_BITS bit;
};


#define TIMER_CTL_TBPWML                ( 0x00004000 ) // GPTM Timer B PWM Output Level
#define TIMER_CTL_TBOTE                 ( 0x00002000 ) // GPTM Timer B Output Trigger
                                                       // Enable
#define TIMER_CTL_TBEVENT_M             ( 0x00000C00 ) // GPTM Timer B Event Mode
#define TIMER_CTL_TBEVENT_POS           ( 0x00000000 ) // Positive edge
#define TIMER_CTL_TBEVENT_NEG           ( 0x00000400 ) // Negative edge
#define TIMER_CTL_TBEVENT_BOTH          ( 0x00000C00 ) // Both edges
#define TIMER_CTL_TBSTALL               ( 0x00000200 ) // GPTM Timer B Stall Enable
#define TIMER_CTL_TBEN                  ( 0x00000100 ) // GPTM Timer B Enable
#define TIMER_CTL_TAPWML                ( 0x00000040 ) // GPTM Timer A PWM Output Level
#define TIMER_CTL_TAOTE                 ( 0x00000020 ) // GPTM Timer A Output Trigger
                                                       // Enable
#define TIMER_CTL_RTCEN                 ( 0x00000010 ) // GPTM RTC Enable
#define TIMER_CTL_TAEVENT_M             ( 0x0000000C ) // GPTM Timer A Event Mode
#define TIMER_CTL_TAEVENT_POS           ( 0x00000000 ) // Positive edge
#define TIMER_CTL_TAEVENT_NEG           ( 0x00000004 ) // Negative edge
#define TIMER_CTL_TAEVENT_BOTH          ( 0x0000000C ) // Both edges
#define TIMER_CTL_TASTALL               ( 0x00000002 ) // GPTM Timer A Stall Enable
#define TIMER_CTL_TAEN                  ( 0x00000001 ) // GPTM Timer A Enable
/*
 * GPTM Control (GPTMCTL) Register, (Page 313 TRM)
 */
struct GPTMCTL_BITS {
    uint32_t TAEN       :       1;

    uint32_t TASTALL    :       1;

    uint32_t TAEVENT    :       2;

    uint32_t RTCEN      :       1;

    uint32_t RSVRD1     :       1;

    uint32_t TAPWML     :       1;

    uint32_t RSVRD2     :       1;

    uint32_t TBEN       :       1;

    uint32_t TBSTALL    :       1;

    uint32_t TBEVENT    :       2;

    uint32_t RSVRD3     :       2;

    uint32_t TBPWML     :       1;

    uint32_t RSVRD4     :       17;
};

union GPTMCTL_REG {
    uint32_t    all;

    struct      GPTMCTL_BITS bit;
};


#define TIMER_TIMB_MATCH            ( 0x00000800 )   // TimerB match interrupt
#define TIMER_CAPB_EVENT            ( 0x00000400 )   // CaptureB event interrupt
#define TIMER_CAPB_MATCH            ( 0x00000200 )   // CaptureB match interrupt
#define TIMER_TIMB_TIMEOUT          ( 0x00000100 )   // TimerB time out interrupt
#define TIMER_TIMA_MATCH            ( 0x00000010 )   // TimerA match interrupt
#define TIMER_RTC_MATCH             ( 0x00000008 )   // RTC interrupt mask
#define TIMER_CAPA_EVENT            ( 0x00000004 )   // CaptureA event interrupt
#define TIMER_CAPA_MATCH            ( 0x00000002 )   // CaptureA match interrupt
#define TIMER_TIMA_TIMEOUT          ( 0x00000001 )   // TimerA time out interrupt
/*
 * GPTM Interrupt Mask (GPTMIMR) Register, (Page 314 TRM)
 */
struct GPTMIMR_BITS {
    uint32_t TATOIM     :       1;

    uint32_t CAMIM      :       1;

    uint32_t CAEIM      :       1;

    uint32_t RTCIM      :       1;

    uint32_t TAMIM      :       1;

    uint32_t RSVRD1     :       3;

    uint32_t TBTOIM     :       1;

    uint32_t CBMIM      :       1;

    uint32_t CBEIM      :       1;

    uint32_t TBMIM      :       1;

    uint32_t RSVRD2     :       20;
};

union GPTMIMR_REG {
    uint32_t    all;

    struct      GPTMIMR_BITS bit;
};


/*
 * GPTM Raw Interrupt Status (GPTMRIS) Register, (Page 316 TRM)
 */
struct GPTMRIS_BITS {
    uint32_t TATORIS    :       1;

    uint32_t CAMRIS     :       1;

    uint32_t CAERIS     :       1;

    uint32_t RTCRIS     :       1;

    uint32_t TAMRIS     :       1;

    uint32_t RSVRD1     :       3;

    uint32_t TBTORIS    :       1;

    uint32_t CBMRIS     :       1;

    uint32_t CBERIS     :       1;

    uint32_t TBMRIS     :       1;

    uint32_t RSVRD2     :       20;
};

union GPTMRIS_REG {
    uint32_t    all;

    struct      GPTMRIS_BITS bit;
};


/*
 * GPTM Masked Interrupt Status (GPTMMIS) Register, (Page 317 TRM)
 */
struct GPTMMIS_BITS {
    uint32_t TATOMIS    :       1;

    uint32_t CAMMIS     :       1;

    uint32_t CAEMIS     :       1;

    uint32_t RTCMIS     :       1;

    uint32_t TAMMIS     :       1;

    uint32_t RSVRD1     :       3;

    uint32_t TBTOMIS    :       1;

    uint32_t CBMMIS     :       1;

    uint32_t CBEMIS     :       1;

    uint32_t TBMMIS     :       1;

    uint32_t RSVRD2     :       20;
};

union GPTMMIS_REG {
    uint32_t    all;

    struct      GPTMMIS_BITS bit;
};

/*
 * GPTM Interrupt Clear (GPTMICR) Register, (Page 317 TRM)
 */
struct GPTMICR_BITS {
    uint32_t TATOCINT   :       1;

    uint32_t CAMCINT    :       1;

    uint32_t CAECINT    :       1;

    uint32_t RTCCINT    :       1;

    uint32_t TAMCINT    :       1;

    uint32_t RSVRD1     :       3;

    uint32_t TBTOCINT   :       1;

    uint32_t CBMCINT    :       1;

    uint32_t CBECINT    :       1;

    uint32_t TBMCINT    :       1;

    uint32_t RSVRD2     :       20;
};

union GPTMICR_REG {
    uint32_t    all;

    struct      GPTMICR_BITS bit;
};


/*
 * GPTM Timer A Interval Load (GPTMTAILR) Register, (Page 318 TRM)
 */
struct GPTMTAILR_BITS {
    uint32_t TAILR      :       32;

};

union GPTMTAILR_REG {
    uint32_t    all;

    struct      GPTMTAILR_BITS bit;
};


/*
 * GPTM Timer B Interval Load (GPTMTBILR) Register, (Page 319 TRM)
 */
struct GPTMTBILR_BITS {
    uint32_t TBILR      :       16;

    uint32_t RSVRD      :       16;
};

union GPTMTBILR_REG {
    uint32_t    all;

    struct      GPTMTBILR_BITS bit;
};


/*
 * GPTM Timer A Match (GPTMTAMATCHR) Register, (Page 319 TRM)
 */
struct GPTMTAMATCHR_BITS {
    uint32_t TAMR      :       32;

};

union GPTMTAMATCHR_REG {
    uint32_t    all;

    struct      GPTMTAMATCHR_BITS bit;
};


/*
 * GPTM Timer B Match (GPTMTBMATCHR) Register, (Page 320 TRM)
 */
struct GPTMTBMATCHR_BITS {
    uint32_t TBMR      :       16;

    uint32_t RSVRD      :       16;
};

union GPTMTBMATCHR_REG {
    uint32_t    all;

    struct      GPTMTBMATCHR_BITS bit;
};


/*
 * GPTM Timer A Prescale (GPTMTAPR) Register, (Page 320 TRM)
 */
struct GPTMTAPR_BITS {
    uint32_t TAPSR      :       8;

    uint32_t RSVRD      :       24;
};
union GPTMTAPR_REG {
    uint32_t    all;

    struct      GPTMTAPR_BITS bit;
};


/*
 * GPTM Timer B Prescale (GPTMTBPR) Register, (Page 321 TRM)
 */
struct GPTMTBPR_BITS {
    uint32_t TBPSR      :       8;

    uint32_t RSVRD      :       24;
};
union GPTMTBPR_REG {
    uint32_t    all;

    struct      GPTMTBPR_BITS bit;
};


/*
 * GPTM Timer A Prescale Match (GPTMTAPMR) Register, (Page 321 TRM)
 */
struct GPTMTAPMR_BITS {
    uint32_t TAPSMR     :       8;

    uint32_t RSVRD      :       24;
};
union GPTMTAPMR_REG {
    uint32_t    all;

    struct      GPTMTAPMR_BITS bit;
};



/*
 * GPTM Timer B Prescale Match (GPTMTBPMR) Register, (Page 321 TRM)
 */
struct GPTMTBPMR_BITS {
    uint32_t TBPSMR     :       8;

    uint32_t RSVRD      :       24;
};
union GPTMTBPMR_REG {
    uint32_t    all;

    struct      GPTMTBPMR_BITS bit;
};


/*
 * GPTM Timer A (GPTMTAR) Register,(Page 322 TRM)
 */
struct GPTMTAR_BITS {
    uint32_t TAR        :       32;
};

union GPTMTAR_REG {
    uint32_t    all;

    struct      GPTMTAR_BITS bit;
};


/*
 * GPTM Timer B (GPTMTBR) Register,(Page 322 TRM)
 */
struct GPTMTBR_BITS {
    uint32_t TBR        :       16;

    uint32_t RSVRD      :       16;
};

union GPTMTBR_REG {
    uint32_t    all;

    struct      GPTMTBR_BITS bit;
};


/*
 * GPTM Timer A Value (GPTMTAV) Register,,(Page 323 TRM)
 */
struct GPTMTAV_BITS {
    uint32_t TAV        :       32;
};

union GPTMTAV_REG {
    uint32_t    all;

    struct      GPTMTAV_BITS bit;
};


/*
 * GPTM Timer B Value (GPTMTBV) Register,,(Page 323 TRM)
 */
struct GPTMTBV_BITS {
    uint32_t TBV        :       16;

    uint32_t RSVRD      :       16;
};

union GPTMTBV_REG {
    uint32_t    all;

    struct      GPTMTBV_BITS bit;
};


/*
 * General Purpose Timers (GPTM) Registers (Page 309 TRM)
 */
struct GPTM_REGS
{
    union GPTMCFG_REG                           GPTMCFG;

    union GPTMTAMR_REG                          GPTMTAMR;

    union GPTMTBMR_REG                          GPTMTBMR;

    union GPTMCTL_REG                           GPTMCTL;

    uint32_t RSVRD1[ ( 0x18 - 0x10 ) >> 2 ];

    union GPTMIMR_REG                           GPTMIMR;

    union GPTMRIS_REG                           GPTMRIS;

    union GPTMMIS_REG                           GPTMMIS;

    union GPTMICR_REG                           GPTMICR;

    union GPTMTAILR_REG                         GPTMTAILR;

    union GPTMTBILR_REG                         GPTMTBILR;

    union GPTMTAMATCHR_REG                      GPTMTAMATCHR;

    union GPTMTBMATCHR_REG                      GPTMTBMATCHR;

    union GPTMTAPR_REG                          GPTMTAPR;

    union GPTMTBPR_REG                          GPTMTBPR;

    union GPTMTAPMR_REG                         GPTMTAPMR;

    union GPTMTBPMR_REG                         GPTMTBPMR;

    union GPTMTAR_REG                           GPTMTAR;

    union GPTMTBR_REG                           GPTMTBR;

    union GPTMTAV_REG                           GPTMTAV;

    union GPTMTBV_REG                           GPTMTBV;
};

/*
extern volatile struct GPTM_REGS GPTM0Regs;

extern volatile struct GPTM_REGS GPTM1Regs;

extern volatile struct GPTM_REGS GPTM2Regs;

extern volatile struct GPTM_REGS GPTM3Regs;
*/

#ifdef __cplusplus
}
#endif


#endif /* __F28M35H52C1_GPTMREGS_H__ */
