/*
 * File: F28M35H52C1_NVICRegs.h
 */

#ifndef __F28M35H52C1_NVICREGS_H__
#define __F28M35H52C1_NVICREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Interrupt 0-31 Set Enable (EN0) Register, (Page 1760 TRM)
 */
struct EN0_BITS {
	uint32_t INT_GPIOA		: 	1;		// 16 GPIO Port A
	
	uint32_t INT_GPIOB      : 	1;		// 17 GPIO Port B
	
	uint32_t INT_GPIOC      : 	1;		// 18 GPIO Port C
	
	uint32_t INT_GPIOD      : 	1;		// 19 GPIO Port D
	
	uint32_t INT_GPIOE      : 	1;		// 20 GPIO Port E
	
	uint32_t INT_UART0      : 	1;		// 21 UART0 Rx and Tx
	
	uint32_t INT_UART1      : 	1;		// 22 UART1 Rx and Tx
	
	uint32_t INT_SSI0       : 	1;		// 23 SSI0 Rx and Tx
	
	uint32_t INT_I2C0       : 	1;		// 24 I2C0 Master and Slave
	
	uint32_t RSVRD1			:	9;
	
	uint32_t INT_WATCHDOG   : 	1;		// 34 Watchdog timer
	
	uint32_t INT_TIMER0A    : 	1;		// 35 Timer 0 subtimer A
	
	uint32_t INT_TIMER0B    : 	1;		// 36 Timer 0 subtimer B
	
	uint32_t INT_TIMER1A    : 	1;		// 37 Timer 1 subtimer A
	
	uint32_t INT_TIMER1B    : 	1;		// 38 Timer 1 subtimer B
	
	uint32_t INT_TIMER2A    : 	1;		// 39 Timer 2 subtimer A
	
	uint32_t INT_TIMER2B    : 	1;		// 40 Timer 2 subtimer B
	
	uint32_t RSVRD2			:	3;
	
	uint32_t INT_SYSCTL     : 	1;		// 44 System Control (PLL, OSC, BO)
	
	uint32_t RSVRD3			:	1;
	
	uint32_t INT_GPIOF      : 	1;		// 46 GPIO Port F
	
	uint32_t INT_GPIOG      : 	1;		// 47 GPIO Port G
};

union EN0_REG {
    uint32_t    all;

    struct      EN0_BITS bit;
};



/*
 * Interrupt 32-63 Set Enable 1 (EN1) Register, (Page 1761 TRM)
 */
struct EN1_BITS {
	
	uint32_t INT_GPIOH      :	1;		// 48 GPIO Port H
	
	uint32_t INT_UART2      :	1;		// 49 UART2 Rx and Tx
	
	uint32_t INT_SSI1       :	1;		// 50 SSI1 Rx and Tx
	
	uint32_t INT_TIMER3A    :	1;		// 51 Timer 3 subtimer A
	
	uint32_t INT_TIMER3B    :	1;		// 52 Timer 3 subtimer B
	
	uint32_t INT_I2C1       :	1;		// 53 I2C1 Master and Slave
	
	uint32_t RSVRD4			:	4;
	
	uint32_t INT_ETH        :	1;		// 58 EMAC
	
	uint32_t RSVRD5			:	1;
	
	uint32_t INT_USB0       :	1;		// 60 USB Controller
	
	uint32_t RSVRD6			:	1;
	
	uint32_t INT_UDMA       :	1;		// 62 uDMA Software
	
	uint32_t INT_UDMAERR    :	1;		// 63 uDMA Error
	
	uint32_t RSVRD7			:	5;
		
	uint32_t INT_EPI0   	:	1;		// 69 EPI
					
	uint32_t INT_GPIOJ  	:	1;		// 70 GPIO Port J
					
	uint32_t RSVRD8     	:	2;	
					
	uint32_t INT_SSI2   	:	1;		// 73 SSI2
					
	uint32_t INT_SSI3   	:	1;		// 74 SSI3
							
	uint32_t INT_UART3  	:	1;		// 75 UART3
							
	uint32_t INT_UART4  	:	1;		// 76 UART4
					
	uint32_t RSVRD9 		:	3;
};

union EN1_REG {
    uint32_t    all;

    struct      EN1_BITS bit;
};



/*
 * Interrupt 64-91 Set Enable 2 (EN2) Register, (Page 1761 TRM)
 */
struct EN2_BITS {
	uint32_t INT_CAN0INT0   			:	1;		// 80 CAN 0 INT 0
				
	uint32_t INT_CAN0INT1   			:	1;		// 81 CAN 0 INT 1
				
	uint32_t INT_CAN1INT0   			:	1;		// 82 CAN 1 INT 0
				
	uint32_t INT_CAN1INT1   			:	1;		// 83 CAN 1 INT 1
	
	uint32_t RSVRD10					:	4;
	
	uint32_t INT_ADC1                   :	1;		// 88  ADC Interrupt 1
	
	uint32_t INT_ADC2                   :	1;		// 89  ADC Interrupt 2
	
	uint32_t INT_ADC3                   :	1;		// 90  ADC Interrupt 3
	
	uint32_t INT_ADC4                   :	1;		// 91  ADC Interrupt 4
	
	uint32_t INT_ADC5                   :	1;		// 92  ADC Interrupt 5
	
	uint32_t INT_ADC6                   :	1;		// 93  ADC Interrupt 6
	
	uint32_t INT_ADC7                   :	1;		// 94  ADC Interrupt 7
	
	uint32_t INT_ADC8                   :	1;		// 95  ADC Interrupt 8
	
	uint32_t INT_CTOMPIC1               :	1;		// 96  CtoM IPC1
	
	uint32_t INT_CTOMPIC2               :	1;		// 97  CtoM IPC2
	
	uint32_t INT_CTOMPIC3               :	1;		// 98  CtoM IPC3
	
	uint32_t INT_CTOMPIC4               :	1;		// 99  CtoM IPC4
	
	uint32_t RSVRD11					:	4;
	
	uint32_t INT_RAM_SINGLE_ERROR       :	1;		// 104 RAM Single Error
	
	uint32_t INT_USB_PLL_LOCK           :	1;		// 105 USB PLL Lock
	
	uint32_t INT_M3_FLASH_SINGLE_ERROR  :	1;		// 106 M3 Flash Single Error

	uint32_t RSVRD12					:	5;	
};

union EN2_REG {
    uint32_t    all;

    struct      EN2_BITS bit;
};



/*
 * Interrupt 0-31 Clear Enable (DIS0) Register, (Page 1762 TRM)
 */
struct DIS0_BITS {
    uint32_t INT       :       32;
};

union DIS0_REG {
    uint32_t    all;

    struct      DIS0_BITS bit;
};



/*
 * Interrupt 32-63 Clear Enable (DIS1) Register, (Page 1762 TRM)
 */
struct DIS1_BITS {
    uint32_t INT       :       32;
};

union DIS1_REG {
    uint32_t    all;

    struct      DIS1_BITS bit;
};



/*
 * Interrupt 64-91 Clear Enable (DIS2) Register, (Page 1763 TRM)
 */
struct DIS2_BITS {
    uint32_t INT       :       32;
};

union DIS2_REG {
    uint32_t    all;

    struct      DIS2_BITS bit;
};



/*
 * Interrupt 0-31 Set Pending (PEND0) Register, (Page 1763 TRM)
 */
struct PEND0_BITS {
    uint32_t INT       :       32;
};

union PEND0_REG {
    uint32_t    all;

    struct      PEND0_BITS bit;
};



/*
 * Interrupt 32-63 Set Pending (PEND1) Register, (Page 1764 TRM)
 */
struct PEND1_BITS {
    uint32_t INT       :       32;
};

union PEND1_REG {
    uint32_t    all;

    struct      PEND1_BITS bit;
};



/*
 * Interrupt 64-91 Set Pending (PEND2) Register, (Page 1764 TRM)
 */
struct PEND2_BITS {
    uint32_t INT       :       32;
};

union PEND2_REG {
    uint32_t    all;

    struct      PEND2_BITS bit;
};



/*
 * Interrupt 0-31 Clear Pending (UNPEND0) Register, (Page 1765 TRM)
 */
struct UNPEND0_BITS {
    uint32_t INT       :       32;
};

union UNPEND0_REG {
    uint32_t    all;

    struct      UNPEND0_BITS bit;
};



/*
 * Interrupt 32-63 Clear Pending (UNPEND1) Register, (Page 1765 TRM)
 */
struct UNPEND1_BITS {
    uint32_t INT       :       32;
};

union UNPEND1_REG {
    uint32_t    all;

    struct      UNPEND1_BITS bit;
};



/*
 * Interrupt 64-91 Clear Pending (UNPEND2) Register, (Page 1766 TRM)
 */
struct UNPEND2_BITS {
    uint32_t INT       :       32;
};

union UNPEND2_REG {
    uint32_t    all;

    struct      UNPEND2_BITS bit;
};



/*
 * Interrupt 0-31 Active Bit (ACTIVE0) Register, (Page 1766 TRM)
 */
struct ACTIVE0_BITS {
    uint32_t INT       :       32;
};

union ACTIVE0_REG {
    uint32_t    all;

    struct      ACTIVE0_BITS bit;
};



/*
 * Interrupt 32-63 Active Bit (ACTIVE1) Register, (Page 1767 TRM)
 */
struct ACTIVE1_BITS {
    uint32_t INT       :       32;
};

union ACTIVE1_REG {
    uint32_t    all;

    struct      ACTIVE1_BITS bit;
};



/*
 * Interrupt 64-91 Active Bit (ACTIVE2) Register, (Page 1767 TRM)
 */
struct ACTIVE2_BITS {
    uint32_t INT       :       32;
};

union ACTIVE2_REG {
    uint32_t    all;

    struct      ACTIVE2_BITS bit;
};





/*
 * Interrupt 0-91 Priority (PRI0-PRI22) Registers, (Page 1768 TRM)
 */
struct PRIx_BITS {
    uint32_t RSVRD1         :   5;

    uint32_t INTA           :   3;

    uint32_t RSVRD2         :   5;

    uint32_t INTB           :   3;

    uint32_t RSVRD3         :   5;

    uint32_t INTC           :   3;

    uint32_t RSVRD4         :   5;

    uint32_t INTD           :   3;
};

union PRIx_REG {
    uint32_t    all;

    struct      PRIx_BITS bit;
};


struct NVIC_REGS
{
    union EN0_REG               EN0;

    union EN1_REG               EN1;

    union EN2_REG               EN2;

    uint32_t RSVRD1[( ( 0x180 - 0x10C ) >> 2 )];

    union DIS0_REG              DIS0;

    union DIS1_REG              DIS1;

    union DIS2_REG              DIS2;

    uint32_t RSVRD2[( ( 0x200 - 0x18C ) >> 2 )];

    union PEND0_REG             PEND0;

    union PEND1_REG             PEND1;

    union PEND2_REG             PEND2;

    uint32_t RSVRD3[( ( 0x280 - 0x20C ) >> 2 )];

    union UNPEND0_REG           UNPEND0;

    union UNPEND1_REG           UNPEND1;

    union UNPEND2_REG           UNPEND2;

    uint32_t RSVRD4[( ( 0x300 - 0x28C ) >> 2 )];

    union ACTIVE0_REG           ACTIVE0;

    union ACTIVE1_REG           ACTIVE1;

    union ACTIVE2_REG           ACTIVE2;

    uint32_t RSVRD5[( ( 0x400 - 0x30C ) >> 2 )];

    union PRIx_REG              PRI0;

    union PRIx_REG              PRI1;

    union PRIx_REG              PRI2;

    union PRIx_REG              PRI3;

    union PRIx_REG              PRI4;

    union PRIx_REG              PRI5;

    union PRIx_REG              PRI6;

    union PRIx_REG              PRI7;

    union PRIx_REG              PRI8;

    union PRIx_REG              PRI9;

    union PRIx_REG              PRI10;

    union PRIx_REG              PRI11;

    union PRIx_REG              PRI12;

    union PRIx_REG              PRI13;

    union PRIx_REG              PRI14;

    union PRIx_REG              PRI15;

    union PRIx_REG              PRI16;

    union PRIx_REG              PRI17;

    union PRIx_REG              PRI18;

    union PRIx_REG              PRI19;

    union PRIx_REG              PRI20;

    union PRIx_REG              PRI21;

    union PRIx_REG              PRI22;
};


extern volatile struct NVIC_REGS NVICRegs;


/*
 * Software Trigger Interrupt (SWTRIG) Register, (Page 1768 TRM)
 */
struct SWTRIG_BITS {
    uint32_t INTID          :   6;

    uint32_t RSVRD          :   26;
};

union SWTRIG_REG {
    uint32_t    all;

    struct      SWTRIG_BITS bit;
};

extern volatile union SWTRIG_REG SWTRIGReg;

#ifdef __cplusplus
}
#endif


#endif /* __F28M35H52C1_NVICREGS_H__ */
