/*
 * File: F28M35H52C1_SCBRegs.h
 */

#ifndef __F28M35H52C1_SCBREGS_H__
#define __F28M35H52C1_SCBREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * CPU ID Base (CPUID) Register (Page 1771 TRM)
 */
struct CPUID_BITS {
    uint32_t REV        :       4;      // 0x0

    uint32_t PARTNO     :       12;     // 0xC23 Cortex-M3

    uint32_t CON        :       4;      // 0xF

    uint32_t VAR        :       4;      // 0x2

    uint32_t IMP        :       8;      // 0x41 ARM
};

union CPUID_REG {
    uint32_t    all;

    struct      CPUID_BITS bit;
};


/*
 * Interrupt Control and State (INTCTRL) Register (Page 1772 TRM)
 */
struct INTCTRL_BITS {
    uint32_t VECACT     :       7;

    uint32_t RSVRD1     :       4;

    uint32_t RETBASE    :       1;

    uint32_t VECPEND    :       7;

    uint32_t RSVRD2     :       3;

    uint32_t ISRPEND    :       1;

    uint32_t ISRPRE     :       1;

    uint32_t RSVRD3     :       1;

    uint32_t PENDSTCLR  :       1;

    uint32_t PENDSTSET  :       1;

    uint32_t UNPENDSV   :       1;

    uint32_t PENDSV     :       1;

    uint32_t RSVRD4     :       2;

    uint32_t NMISET     :       1;
};

union INTCTRL_REG {
    uint32_t    all;

    struct      INTCTRL_BITS bit;
};


/*
 * Vector Table Offset (VTABLE) Register (Page 1775 TRM)
 */
struct VTABLE_BITS {
    uint32_t RSVRD1     :       9;

    uint32_t OFFSET     :       20;

    uint32_t BASE       :       1;

    uint32_t RSVRD2     :       2;
};

union VTABLE_REG {
    uint32_t    all;

    struct      VTABLE_BITS bit;
};


/*
 * Application Interrupt and Reset Control (APINT) Register (Page 1776 TRM)
 */
struct APINT_BITS {
    uint32_t VECTRESET  :       1;

    uint32_t VECTCLRACT :       1;

    uint32_t SYSRESREQ  :       1;

    uint32_t RSVRD1     :       5;

    uint32_t PRIGROUP   :       3;

    uint32_t RSVRD2     :       4;

    uint32_t ENDIANESS  :       1;

    uint32_t VECTKEY    :       16;
};

union APINT_REG {
    uint32_t    all;

    struct      APINT_BITS bit;
};


/*
 * System Control (SYSCTRL) Register (Page 1778 TRM)
 */
struct SYSCTRL_BITS {
    uint32_t RSVRD1     :       1;

    uint32_t SLEEPEXIT  :       1;

    uint32_t SLEEPDEEP  :       1;

    uint32_t RSVRD2     :       1;

    uint32_t SEVONPEND  :       1;

    uint32_t RSVRD3     :       27;
};

union SYSCTRL_REG {
    uint32_t    all;

    struct      SYSCTRL_BITS bit;
};


/*
 * Configuration and Control (CFGCTRL) Register (Page 1779 TRM)
 */
struct CFGCTRL_BITS {
    uint32_t BASETHR    :       1;

    uint32_t MAINPEND   :       1;

    uint32_t RSVRD1     :       1;

    uint32_t UNALIGNED  :       1;

    uint32_t DIV0       :       1;

    uint32_t RSVRD2     :       3;

    uint32_t BFHFNMIGN  :       1;

    uint32_t STKALIGN   :       1;

    uint32_t RSVRD3     :       22;
};

union CFGCTRL_REG {
    uint32_t    all;

    struct      CFGCTRL_BITS bit;
};


/*
 * System Handler Priority 1 (SYSPRI1) Register (Page 1780 TRM)
 */
struct SYSPRI1_BITS {
    uint32_t RSVRD1     :       5;

    uint32_t MEM        :       3;

    uint32_t RSVRD2     :       5;

    uint32_t BUS        :       3;

    uint32_t RSVRD3     :       5;

    uint32_t USAGE      :       3;

    uint32_t RSVRD      :       8;
};

union SYSPRI1_REG {
    uint32_t    all;

    struct      SYSPRI1_BITS bit;
};


/*
 * System Handler Priority 2 (SYSPRI2) Register (Page 1781 TRM)
 */
struct SYSPRI2_BITS {
    uint32_t RSVRD      :      29;

    uint32_t SVC        :       3;
};

union SYSPRI2_REG {
    uint32_t    all;

    struct      SYSPRI2_BITS bit;
};


/*
 * System Handler Priority 3 (SYSPRI3) Register (Page 1781 TRM)
 */
struct SYSPRI3_BITS {
    uint32_t RSVRD1     :       5;

    uint32_t DEBUG      :       3;

    uint32_t RSVRD2     :       13;

    uint32_t PENDSV     :       3;

    uint32_t RSVRD3     :       5;

    uint32_t TICK       :       3;
};

union SYSPRI3_REG {
    uint32_t    all;

    struct      SYSPRI3_BITS bit;
};


/*
 * System Handler Control and State (SYSHNDCTRL) (Page 1782 TRM)
 */
struct SYSHNDCTRL_BITS {
    uint32_t MEMA       :       1;

    uint32_t BUSA       :       1;

    uint32_t RSVD1      :       1;

    uint32_t USGA       :       1;

    uint32_t RSVD2      :       3;

    uint32_t SVCA       :       1;

    uint32_t MON        :       1;

    uint32_t RSVD3      :       1;

    uint32_t PNDSV      :       1;

    uint32_t TICK       :       1;

    uint32_t USAGEP     :       1;

    uint32_t MEMP       :       1;

    uint32_t BUSP       :       1;

    uint32_t SVC        :       1;

    uint32_t MEM        :       1;

    uint32_t BUS        :       1;

    uint32_t USAGE      :       1;

    uint32_t RSVD4      :       13;
};

union SYSHNDCTRL_REG {
    uint32_t    all;

    struct      SYSHNDCTRL_BITS bit;
};


/*
 * Configurable Fault Status (FAULTSTAT) Register (Page 1785 TRM)
 */
struct FAULTSTAT_BITS {
    uint32_t IERR       :       1;

    uint32_t DERR       :       1;

    uint32_t RSVRD1     :       1;

    uint32_t MUSTKE     :       1;

    uint32_t MSTKE      :       1;

    uint32_t RSVRD2     :       2;

    uint32_t MMARV      :       1;

    uint32_t IBUS       :       1;

    uint32_t PRECISE    :       1;

    uint32_t IMPRE      :       1;

    uint32_t BUSTKE     :       1;

    uint32_t BSTKE      :       1;

    uint32_t RSVRD3     :       2;

    uint32_t BFARV      :       1;

    uint32_t UNDEF      :       1;

    uint32_t INVSTAT    :       1;

    uint32_t INVPC      :       1;

    uint32_t NOCP       :       1;

    uint32_t RSVRD4     :       4;

    uint32_t UNALIGN    :       1;

    uint32_t DIV0       :       1;

    uint32_t RSVRD5     :       6;
};

union FAULTSTAT_REG {
    uint32_t    all;

    struct      FAULTSTAT_BITS bit;
};


/*
 * Hard Fault Status (HFAULTSTAT) (Page 1788 TRM)
 */
struct HFAULTSTAT_BITS {
    uint32_t RSVRD1     :       1;

    uint32_t VECT       :       1;

    uint32_t RSVRD2     :       28;

    uint32_t DBG        :       1;

    uint32_t FORCED     :       1;
};

union HFAULTSTAT_REG {
    uint32_t    all;

    struct      HFAULTSTAT_BITS bit;
};


/*
 * Memory Management Fault Address (MMADDR) Register (Page 1790 TRM)
 */
struct MMADDR_BITS {
    uint32_t ADDR       :       32;
};

union MMADDR_REG {
    uint32_t    all;

    struct      MMADDR_BITS bit;
};


/*
 * Bus Fault Address (FAULTADDR) Register, Register (Page 1790 TRM)
 */
struct FAULTADDR_BITS {
    uint32_t ADDR       :       32;
};

union FAULTADDR_REG {
    uint32_t    all;

    struct      FAULTADDR_BITS bit;
};


/*
 * System Control Block (SCB) Registers (Page 1756 TRM)
 */
struct SCB_REGS
{
    union CPUID_REG                         CPUID;

    union INTCTRL_REG                       INTCTRL;

    union VTABLE_REG                        VTABLE;

    union APINT_REG                         APINT;

    union SYSCTRL_REG                       SYSCTRL;

    union CFGCTRL_REG                       CFGCTRL;

    union SYSPRI1_REG                       SYSPRI1;

    union SYSPRI2_REG                       SYSPRI2;

    union SYSPRI3_REG                       SYSPRI3;

    union SYSHNDCTRL_REG                    SYSHNDCTRL;

    union FAULTSTAT_REG                     FAULTSTAT;

    union HFAULTSTAT_REG                    HFAULTSTAT;

    uint32_t RSVRD1;

    union MMADDR_REG                        MMADDR;

    union FAULTADDR_REG                     FAULTADDR;
};

extern volatile struct SCB_REGS SCBRegs;

#ifdef __cplusplus
}
#endif


#endif /* __F28M35H52C1_SCBREGS_H__ */
