/*
 * File: F28M35H52C1_SysCtlRegs.h
 */

#ifndef __F28M35H52C1_SYSCTLREGS_H__
#define __F28M35H52C1_SYSCTLREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Device Identification 0 (DID0) Register,(Page 179 TRM)
 */
struct DID0_BITS {
    uint32_t REVID      :       16;

    uint32_t CLASS      :       8;

    uint32_t RSVRD1     :       4;

    uint32_t VER        :       3;

    uint32_t RSVRD2     :       1;
};

union DID0_REG {
    uint32_t    all;

    struct      DID0_BITS bit;
};



/*
 * Device Identification 0 (DID0) Register,(Page 179 TRM)
 */
struct DID1_BITS {
    uint32_t QUAL       :       2;

    uint32_t ROHS       :       1;

    uint32_t PACKAGE    :       2;

    uint32_t TEMP       :       3;

    uint32_t RSVRD1     :       5;

    uint32_t PINCOUNT   :       5;

    uint32_t PARTNO     :       8;

    uint32_t FAM        :       4;

    uint32_t VER        :       4;
};

union DID1_REG {
    uint32_t    all;

    struct      DID1_BITS bit;
};



/*
 * Device Configuration 1 (DC1) Register,(Page 180 TRM)
 */
struct DC1_BITS {
    uint32_t JTAG       :       1;

    uint32_t RSVRD1     :       2;

    uint32_t WDT0       :       1;

    uint32_t PLL        :       1;

    uint32_t RSVRD2     :      23;

    uint32_t WDT1       :       1;

    uint32_t RSVRD3     :       3;
};

union DC1_REG {
    uint32_t    all;

    struct      DC1_BITS bit;
};



/*
 * Device Configuration 2 (DC2) Register,(Page 181 TRM)
 * MWRALLOW
 */
struct DC2_BITS {
    uint32_t UART0      :       1;

    uint32_t UART1      :       1;

    uint32_t UART2      :       1;

    uint32_t UART3      :       1;

    uint32_t SSI0       :       1;

    uint32_t SSI1       :       1;

    uint32_t SSI2       :       1;

    uint32_t SSI3       :       1;

    uint32_t RSVRD1     :       4;

    uint32_t I2C0       :       1;

    uint32_t RSVRD2     :       1;

    uint32_t I2C1       :       1;

    uint32_t RSVRD3     :       1;

    uint32_t TIMRER0    :       1;

    uint32_t TIMRER1    :       1;

    uint32_t TIMRER2    :       1;

    uint32_t TIMRER3    :       1;

    uint32_t RSVRD4     :       10;

    uint32_t EPI        :       1;

    uint32_t RSVRD5     :       1;
};

union DC2_REG {
    uint32_t    all;

    struct      DC2_BITS bit;
};



/*
 * Device Configuration 4 (DC4) Register,(Page 183 TRM)
 * MWRALLOW
 */
struct DC4_BITS {
    uint32_t GPIOA      :       1;

    uint32_t GPIOB      :       1;

    uint32_t GPIOC      :       1;

    uint32_t GPIOD      :       1;

    uint32_t GPIOE      :       1;

    uint32_t GPIOF      :       1;

    uint32_t GPIOG      :       1;

    uint32_t GPIOH      :       1;

    uint32_t GPIOJ      :       1;

    uint32_t RSVRD1     :       3;

    uint32_t ROM        :       1;

    uint32_t uDMA       :       1;

    uint32_t RSVRD2     :       10;

    uint32_t E1558      :       1;

    uint32_t RSVRD3     :       3;

    uint32_t EMAC0      :       1;

    uint32_t RSVRD4     :       3;

};

union DC4_REG {
    uint32_t    all;

    struct      DC4_BITS bit;
};



/*
 * Device Configuration 6 (DC6) Register,(Page 185 TRM)
 * MWRALLOW
 */
struct DC6_BITS {
    uint32_t USB0       :       2;

    uint32_t RSVRD1     :       2;

    uint32_t USBPHY0    :       1;

    uint32_t RSVRD2     :       27;

};

union DC6_REG {
    uint32_t    all;

    struct      DC6_BITS bit;
};



/*
 * Device Configuration 7 (DC7) Register,(Page 186 TRM)
 */
struct DC7_BITS {
    uint32_t FLASH      :       3;

    uint32_t RSVRD1     :       5;

    uint32_t uCRC       :       1;

    uint32_t RSVRD2     :       23;

};

union DC7_REG {
    uint32_t    all;

    struct      DC7_BITS bit;
};



/*
 * Software Reset Control 0 (SRCR0) Register,(Page 196 TRM)
 * MWRALLOW
 */
struct SRCR0_BITS {
    uint32_t RSVRD1     :       3;

    uint32_t WDT0       :       1;

    uint32_t RSVRD2     :       24;

    uint32_t WDT1       :       1;

    uint32_t RSVRD3     :       3;

};

union SRCR0_REG {
    uint32_t    all;

    struct      SRCR0_BITS bit;
};



/*
 * Software Reset Control 1 (SRCR1) Register,(Page 198 TRM)
 * MWRALLOW
 */
struct SRCR1_BITS {
    uint32_t UART0      :       1;

    uint32_t UART1      :       1;

    uint32_t UART2      :       1;

    uint32_t UART3      :       1;

    uint32_t SSI0       :       1;

    uint32_t SSI1       :       1;

    uint32_t SSI2       :       1;

    uint32_t SSI3       :       1;

    uint32_t RSVRD1     :       4;

    uint32_t I2C0       :       1;

    uint32_t RSVRD2     :       1;

    uint32_t I2C1       :       1;

    uint32_t RSVRD3     :       1;

    uint32_t TIMER0     :       1;

    uint32_t TIMER1     :       1;

    uint32_t TIMER2     :       1;

    uint32_t TIMER3     :       1;

    uint32_t RSVRD4     :       10;

    uint32_t EPI        :       1;

    uint32_t RSVRD5     :       1;

};

union SRCR1_REG {
    uint32_t    all;

    struct      SRCR1_BITS bit;
};



/*
 * Software Reset Control 2 (SRCR2) Register,(Page 199 TRM)
 * MWRALLOW
 */
struct SRCR2_BITS {
    uint32_t GPIOA      :       1;

    uint32_t GPIOB      :       1;

    uint32_t GPIOC      :       1;

    uint32_t GPIOD      :       1;

    uint32_t GPIOE      :       1;

    uint32_t GPIOF      :       1;

    uint32_t GPIOG      :       1;

    uint32_t GPIOH      :       1;

    uint32_t GPIOJ      :       1;

    uint32_t RSVRD1     :       4;

    uint32_t uDMA       :       1;

    uint32_t RSVRD2     :       2;

    uint32_t USB        :       1;

    uint32_t RSVRD3     :       11;

    uint32_t EMAC0      :       1;

    uint32_t RSVRD4     :       3;

};

union SRCR2_REG {
    uint32_t    all;

    struct      SRCR2_BITS bit;
};



/*
 * Software Reset Control 3 (SRCR3) Register,(Page 200 TRM)
 * MWRALLOW
 */
struct SRCR3_BITS {
    uint32_t UART4      :       1;

    uint32_t RSVRD1     :       23;

    uint32_t CAN0       :       1;

    uint32_t CAN1       :       1;

    uint32_t RSVRD2     :       6;

};

union SRCR3_REG {
    uint32_t    all;

    struct      SRCR3_BITS bit;
};



/*
 * Master Reset Cause (MRESC) Register,(Page 195 TRM)
 */
struct MRESC_BITS {
    uint32_t XRS            :       1;

    uint32_t POR            :       1;

    uint32_t RSVRD1         :       1;

    uint32_t WDT0           :       1;

    uint32_t SW             :       1;

    uint32_t WDT1           :       1;

    uint32_t RSVRD2         :       10;

    uint32_t MCLKNMI        :       1;

    uint32_t RSVRD3         :       7;

    uint32_t EXTGPIO        :       1;

    uint32_t HWBIST         :       2;

    uint32_t C28PIENMI      :       1;

    uint32_t C28BISTERRNMI  :       1;

    uint32_t M3BISTERRNMI   :       1;

    uint32_t C28NMIWDRST    :       1;

    uint32_t ACIBERRNMI     :       1;

};

union MRESC_REG {
    uint32_t    all;

    struct      MRESC_BITS bit;
};



/*
 * Run Mode Clock Configuration (RCC) Register,(Page 230 TRM)
 * MWRALLOW
 */
struct RCC_BITS {
    uint32_t RSVRD1         :       27;

    uint32_t ACG            :       1;

    uint32_t RSVRD2         :       4;

};

union RCC_REG {
    uint32_t    all;

    struct      RCC_BITS bit;
};



/*
 * Master GPIO High Performance Bus Control (GPIOHBCTL) Register,(Page 231 TRM)
 * MWRALLOW
 */
struct GPIOHBCTL_BITS {
    uint32_t PORTA          :       1;

    uint32_t PORTB          :       1;

    uint32_t PORTC          :       1;

    uint32_t PORTD          :       1;

    uint32_t PORTE          :       1;

    uint32_t PORTF          :       1;

    uint32_t PORTG          :       1;

    uint32_t PORTH          :       1;

    uint32_t PORTJ          :       1;

    uint32_t RSVRD          :       23;

};

union GPIOHBCTL_REG {
    uint32_t    all;

    struct      GPIOHBCTL_BITS bit;
};



/*
 * Run Mode Clock Gating Control Register 0 (RCGC0) Register,(Page 232 TRM)
 * MWRALLOW
 */
struct RCGC0_BITS {
    uint32_t RSVRD1         :       3;

    uint32_t WDT0           :       1;

    uint32_t RSVRD2         :       24;

    uint32_t WDT1           :       1;

    uint32_t RSVRD3         :       3;

};

union RCGC0_REG {
    uint32_t    all;

    struct      RCGC0_BITS bit;
};



/*
 * Run Mode Clock Gating Control Register 1 (RCGC1) Register,(Page 233 TRM)
 * MWRALLOW
 */
struct RCGC1_BITS {
    uint32_t UART0          :       1;

    uint32_t UART1          :       1;

    uint32_t UART2          :       1;

    uint32_t UART3          :       1;

    uint32_t SSI0           :       1;

    uint32_t SSI1           :       1;

    uint32_t SSI2           :       1;

    uint32_t SSI3           :       1;

    uint32_t RSVRD1         :       4;

    uint32_t I2C0           :       1;

    uint32_t RSVRD2         :       1;

    uint32_t I2C1           :       1;

    uint32_t RSVRD3         :       1;

    uint32_t TIMER0         :       1;

    uint32_t TIMER1         :       1;

    uint32_t TIMER2         :       1;

    uint32_t TIMER3         :       1;

    uint32_t RSVRD4         :       10;

    uint32_t EPI            :       1;

    uint32_t RSVRD5         :       1;

};

union RCGC1_REG {
    uint32_t    all;

    struct      RCGC1_BITS bit;
};



/*
 * Run Mode Clock Gating Control Register 2 (RCGC2) Register,(Page 238 TRM)
 * MWRALLOW
 */
struct RCGC2_BITS {
    uint32_t GPIOA          :       1;

    uint32_t GPIOB          :       1;

    uint32_t GPIOC          :       1;

    uint32_t GPIOD          :       1;

    uint32_t GPIOE          :       1;

    uint32_t GPIOF          :       1;

    uint32_t GPIOG          :       1;

    uint32_t GPIOH          :       1;

    uint32_t GPIOJ          :       1;

    uint32_t RSVRD1         :       4;

    uint32_t uDMA           :       1;

    uint32_t RSVRD2         :       2;

    uint32_t USB            :       1;

    uint32_t RSVRD3         :       11;

    uint32_t EMAC0          :       1;

    uint32_t RSVRD4         :       3;

};

union RCGC2_REG {
    uint32_t    all;

    struct      RCGC2_BITS bit;
};



/*
 * Run Mode Clock Gating Control Register 3 (RCGC3) Register,(Page 242 TRM)
 * MWRALLOW
 */
struct RCGC3_BITS {
    uint32_t UART4          :       1;

    uint32_t RSVRD1         :       23;

    uint32_t CAN0           :       1;

    uint32_t CAN1           :       1;

    uint32_t RSVRD2         :       6;

};

union RCGC3_REG {
    uint32_t    all;

    struct      RCGC3_BITS bit;
};



/*
 * Sleep Mode Clock Gating Control (SCGC0) Register, (Page 232 TRM)
 * MWRALLOW
 */
struct SCGC0_BITS {
    uint32_t RSVRD1         :       3;

    uint32_t WDT0           :       1;

    uint32_t RSVRD2         :       24;

    uint32_t WDT1           :       1;

    uint32_t RSVRD3         :       3;
};

union SCGC0_REG {
    uint32_t    all;

    struct      SCGC0_BITS bit;
};



/*
 * Sleep Mode Clock Gating Control (SCGC1) Register, (Page 235 TRM)
 * MWRALLOW
 */
struct SCGC1_BITS {
    uint32_t UART0          :       1;

    uint32_t UART1          :       1;

    uint32_t UART2          :       1;

    uint32_t UART3          :       1;

    uint32_t SSI0           :       1;

    uint32_t SSI1           :       1;

    uint32_t SSI2           :       1;

    uint32_t SSI3           :       1;

    uint32_t RSVRD1         :       4;

    uint32_t I2C0           :       1;

    uint32_t RSVRD2         :       1;

    uint32_t I2C1           :       1;

    uint32_t RSVRD3         :       1;

    uint32_t TIMER0         :       1;

    uint32_t TIMER1         :       1;

    uint32_t TIMER2         :       1;

    uint32_t TIMER3         :       1;

    uint32_t RSVRD4         :       12;
};

union SCGC1_REG {
    uint32_t    all;

    struct      SCGC1_BITS bit;
};


/*
 * Sleep Mode Clock Gating Control (SCGC2) Register, (Page 239 TRM)
 * MWRALLOW
 */
struct SCGC2_BITS {
    uint32_t GPIOA          :       1;

    uint32_t GPIOB          :       1;

    uint32_t GPIOC          :       1;

    uint32_t GPIOD          :       1;

    uint32_t GPIOE          :       1;

    uint32_t GPIOF          :       1;

    uint32_t GPIOG          :       1;

    uint32_t GPIOH          :       1;

    uint32_t GPIOJ          :       1;

    uint32_t RSVRD1         :       4;

    uint32_t uDMA           :       1;

    uint32_t RSVRD2         :       2;

    uint32_t USB            :       1;

    uint32_t RSVRD3         :       11;

    uint32_t EMAC0          :       1;

    uint32_t RSVRD4         :       3;
};

union SCGC2_REG {
    uint32_t    all;

    struct      SCGC2_BITS bit;
};



/*
 * Sleep Mode Clock Gating Control (SCGC3) Register, (Page 243 TRM)
 * MWRALLOW
 */
struct SCGC3_BITS {
    uint32_t UART4          :       1;

    uint32_t RSVRD1         :       23;

    uint32_t CAN0           :       1;

    uint32_t CAN1           :       1;

    uint32_t RSVRD2         :       6;
};

union SCGC3_REG {
    uint32_t    all;

    struct      SCGC3_BITS bit;
};



/*
 * Deep Sleep Mode Clock Gating Control (DCGC0) Register, (Page 233 TRM)
 * MWRALLOW
 */
struct DCGC0_BITS {
    uint32_t RSVRD1         :       3;

    uint32_t WDT0           :       1;

    uint32_t RSVRD2         :       24;

    uint32_t WDT1           :       1;

    uint32_t RSVRD3         :       3;
};

union DCGC0_REG {
    uint32_t    all;

    struct      DCGC0_BITS bit;
};



/*
 * Deep Sleep Mode Clock Gating Control (DCGC1) Register, (Page 237 TRM)
 * MWRALLOW
 */
struct DCGC1_BITS {
    uint32_t UART0          :       1;

    uint32_t UART1          :       1;

    uint32_t UART2          :       1;

    uint32_t UART3          :       1;

    uint32_t SSI0           :       1;

    uint32_t SSI1           :       1;

    uint32_t SSI2           :       1;

    uint32_t SSI3           :       1;

    uint32_t RSVRD1         :       4;

    uint32_t I2C0           :       1;

    uint32_t RSVRD2         :       1;

    uint32_t I2C1           :       1;

    uint32_t RSVRD3         :       1;

    uint32_t TIMER0         :       1;

    uint32_t TIMER1         :       1;

    uint32_t TIMER2         :       1;

    uint32_t TIMER3         :       1;

    uint32_t RSVRD4         :       10;

    uint32_t EPI            :       1;

    uint32_t RSVRD5         :       1;
};

union DCGC1_REG {
    uint32_t    all;

    struct      DCGC1_BITS bit;
};



/*
 * Deep Sleep Mode Clock Gating Control (DCGC2) Register, (Page 241 TRM)
 * MWRALLOW
 */
struct DCGC2_BITS {
    uint32_t GPIOA          :       1;

    uint32_t GPIOB          :       1;

    uint32_t GPIOC          :       1;

    uint32_t GPIOD          :       1;

    uint32_t GPIOE          :       1;

    uint32_t GPIOG          :       1;

    uint32_t GPIOF          :       1;

    uint32_t GPIOH          :       1;

    uint32_t GPIOJ          :       1;

    uint32_t RSVRD1         :       4;

    uint32_t uDMA           :       1;

    uint32_t RSVRD2         :       2;

    uint32_t USB            :       1;

    uint32_t RSVRD3         :       11;

    uint32_t EMAC0          :       1;

    uint32_t RSVRD4         :       3;
};

union DCGC2_REG {
    uint32_t    all;

    struct      DCGC2_BITS bit;
};



/*
 * Deep Sleep Mode Clock Gating Control (DCGC3) Register, (Page 243 TRM)
 * MWRALLOW
 */
struct DCGC3_BITS {
    uint32_t UART4          :       1;

    uint32_t RSVRD1         :       23;

    uint32_t CAN0           :       1;

    uint32_t CAN1           :       1;

    uint32_t RSVRD2         :       6;
};

union DCGC3_REG {
    uint32_t    all;

    struct      DCGC3_BITS bit;
};



/*
 * Deep Sleep Clock Configuration (DSLPCLKCFG) Register, (Page 243 TRM)
 * MWRALLOW
 */
struct DSLPCLKCFG_BITS {
    uint32_t RSVRD1         :       4;

    uint32_t DSOSCSRC       :       3;

    uint32_t RSVRD2         :       16;

    uint32_t DSDIVOVRIDE    :       4;

    uint32_t RSVRD3         :       5;
};

union DSLPCLKCFG_REG {
    uint32_t    all;

    struct      DSLPCLKCFG_BITS bit;
};



/*
 * Device Configuration 10 (DC10) Register, (Page 185 TRM)
 */
struct DC10_BITS {
    uint32_t UART4          :       1;

    uint32_t RSVRD1         :       23;

    uint32_t CAN0           :       1;

    uint32_t CAN1           :       1;

    uint32_t RSVRD2         :       6;
};

union DC10_REG {
    uint32_t    all;

    struct      DC10_BITS bit;
};


/*
 * Master Subsystem Device Identification and Registers System Control (Page 171 TRM)
 */
struct SYSCTL_REGS
{
    union DID0_REG              DID0;

    union DID1_REG              DID1;

    uint32_t RSVRD1[( ( 0x10 - 0x8 ) >> 2 )];

    union DC1_REG               DC1;

    union DC2_REG               DC2;

    union DC4_REG               DC4;

    uint32_t RSVRD2[( ( 0x24 - 0x20 ) >> 2 )];

    union DC6_REG               DC6;

    union DC7_REG               DC7;

    uint32_t RSVRD3[( ( 0x40 - 0x2C ) >> 2 )];

    union SRCR0_REG             SRCR0;

    union SRCR1_REG             SRCR1;

    union SRCR2_REG             SRCR2;

    union SRCR3_REG             SRCR3;

    uint32_t RSVRD4[( ( 0x5C - 0x50 ) >> 2 )];

    union MRESC_REG             MRESC;

    union RCC_REG               RCC;

    uint32_t RSVRD5[( ( 0x6C - 0x64 ) >> 2 )];

    union GPIOHBCTL_REG         GPIOHBCTL;

    uint32_t RSVRD6[( ( 0x100 - 0x70 ) >> 2 )];

    union RCGC0_REG             RCGC0;

    union RCGC1_REG             RCGC1;

    union RCGC2_REG             RCGC2;

    union RCGC3_REG             RCGC3;

    union SCGC0_REG             SCGC0;

    union SCGC1_REG             SCGC1;

    union SCGC2_REG             SCGC2;

    union SCGC3_REG             SCGC3;

    union DCGC0_REG             DCGC0;

    union DCGC1_REG             DCGC1;

    union DCGC2_REG             DCGC2;

    union DCGC3_REG             DCGC3;

    uint32_t RSVRD7[( ( 0x144 - 0x130 ) >> 2 )];

    union DSLPCLKCFG_REG        DSLPCLKCFG;

    uint32_t RSVRD8[( ( 0x194 - 0x148 ) >> 2 )];

    union DC10_REG              DC10;
};

extern volatile struct SYSCTL_REGS SysCtlRegs;


#ifdef __cplusplus
}
#endif

#endif /* __F28M35H52C1_SYSCTLREGS_H__ */
