/*
 * File: F28M35H52C1_USBRegs.h
 */

#ifndef __F28M35H52C1_USBREGS_H__
#define __F28M35H52C1_USBREGS_H__

#include <stdint.h>

#ifdef __cplusplus
extern "C" {
#endif


/*
 * USB Device Functional Address Register (USBFADDR), (Page 1465 TRM)
 */
struct __attribute__((packed)) USBFADDR_BITS {
    uint8_t FUNCADDR    :       7;

    uint8_t RSVRD       :       1;
};

union __attribute__((packed)) USBFADDR_REG {
    uint8_t    all;

    struct      USBFADDR_BITS bit;
};


/*
 * USB Power Management Register (USBPOWER), (Page 1466 TRM)
 */
struct __attribute__((packed)) USBPOWERH_BITS {
    uint8_t PWRDNPHY    :       1;

    uint8_t SUSPEND     :       1;

    uint8_t RESUME      :       1;

    uint8_t RESET       :       1;

    uint8_t RSVRD       :       4;
};


struct __attribute__((packed)) USBPOWERD_BITS {
    uint8_t PWRDNPHY    :       1;

    uint8_t SUSPEND     :       1;

    uint8_t RESUME      :       1;

    uint8_t RESET       :       1;

    uint8_t RSVRD       :       2;

    uint8_t SOFTCONN    :       1;

    uint8_t ISOUPDATE   :       1;
};


union __attribute__((packed)) USBPOWER_REG {
    uint8_t    all;

    struct      USBPOWERH_BITS bitH;

    struct      USBPOWERD_BITS bitD;
};


/*
 * USB Transmit Interrupt Status Register (USBTXIS), (Page 1467 TRM)
 */
struct __attribute__((packed)) USBTXIS_BITS {
    uint16_t EP0        :       1;

    uint16_t EP1        :       1;

    uint16_t EP2        :       1;

    uint16_t EP3        :       1;

    uint16_t EP4        :       1;

    uint16_t EP5        :       1;

    uint16_t EP6        :       1;

    uint16_t EP7        :       1;

    uint16_t EP8        :       1;

    uint16_t EP9        :       1;

    uint16_t EP10       :       1;

    uint16_t EP11       :       1;

    uint16_t EP12       :       1;

    uint16_t EP13       :       1;

    uint16_t EP14       :       1;

    uint16_t EP15       :       1;
};

union __attribute__((packed)) USBTXIS_REG {
    uint16_t    all;

    struct      USBTXIS_BITS bit;
};


/*
 * USB Receive Interrupt Status Register (USBRXIS), (Page 1470 TRM)
 */
struct __attribute__((packed)) USBRXIS_BITS {
    uint16_t EP0        :       1;

    uint16_t EP1        :       1;

    uint16_t EP2        :       1;

    uint16_t EP3        :       1;

    uint16_t EP4        :       1;

    uint16_t EP5        :       1;

    uint16_t EP6        :       1;

    uint16_t EP7        :       1;

    uint16_t EP8        :       1;

    uint16_t EP9        :       1;

    uint16_t EP10       :       1;

    uint16_t EP11       :       1;

    uint16_t EP12       :       1;

    uint16_t EP13       :       1;

    uint16_t EP14       :       1;

    uint16_t EP15       :       1;
};

union __attribute__((packed)) USBRXIS_REG {
    uint16_t    all;

    struct      USBRXIS_BITS bit;
};


/*
 * USB Transmit Interrupt Enable Register (USBTXIE), (Page 1472 TRM)
 */
struct __attribute__((packed)) USBTXIE_BITS {
    uint16_t EP0        :       1;

    uint16_t EP1        :       1;

    uint16_t EP2        :       1;

    uint16_t EP3        :       1;

    uint16_t EP4        :       1;

    uint16_t EP5        :       1;

    uint16_t EP6        :       1;

    uint16_t EP7        :       1;

    uint16_t EP8        :       1;

    uint16_t EP9        :       1;

    uint16_t EP10       :       1;

    uint16_t EP11       :       1;

    uint16_t EP12       :       1;

    uint16_t EP13       :       1;

    uint16_t EP14       :       1;

    uint16_t EP15       :       1;
};

union __attribute__((packed)) USBTXIE_REG {
    uint16_t    all;

    struct      USBTXIE_BITS bit;
};


/*
 * USB Receive Interrupt Enable Register (USBRXIE), (Page 1474 TRM)
 */
struct __attribute__((packed)) USBRXIE_BITS {
    uint16_t EP0        :       1;

    uint16_t EP1        :       1;

    uint16_t EP2        :       1;

    uint16_t EP3        :       1;

    uint16_t EP4        :       1;

    uint16_t EP5        :       1;

    uint16_t EP6        :       1;

    uint16_t EP7        :       1;

    uint16_t EP8        :       1;

    uint16_t EP9        :       1;

    uint16_t EP10       :       1;

    uint16_t EP11       :       1;

    uint16_t EP12       :       1;

    uint16_t EP13       :       1;

    uint16_t EP14       :       1;

    uint16_t EP15       :       1;
};

union __attribute__((packed)) USBRXIE_REG {
    uint16_t    all;

    struct      USBRXIE_BITS bit;
};


/*
 * USB General Interrupt Status Register (USBIS), (Page 1476 TRM)
 */
struct __attribute__((packed)) USBISH_BITS {
    uint8_t RSVRD       :       1;

    uint8_t RESUME      :       1;

    uint8_t BABBLE      :       1;

    uint8_t SOF         :       1;

    uint8_t CONN        :       1;

    uint8_t DISCON      :       1;

    uint8_t SESREQ      :       1;

    uint8_t VBUSERR     :       1;
};


#define USB_INTERRUPT_STATUS_MASK ( 0x27 )

struct __attribute__((packed)) USBISD_BITS {
    uint8_t SUSPEND     :       1;

    uint8_t RESUME      :       1;

    uint8_t RESET       :       1;

    uint8_t SOF         :       1;

    uint8_t RSVRD1      :       1;

    uint8_t DISCON      :       1;

    uint8_t RSVRD2      :       2;
};


union __attribute__((packed)) USBIS_REG {
    uint8_t    all;

    struct      USBISH_BITS bitH;

    struct      USBISD_BITS bitD;
};


/*
 * USB Interrupt Enable Register (USBIE), (Page 1478 TRM)
 */
struct __attribute__((packed)) USBIEH_BITS {
    uint8_t RSVRD       :       1;

    uint8_t RESUME      :       1;

    uint8_t BABBLE      :       1;

    uint8_t SOF         :       1;

    uint8_t CONN        :       1;

    uint8_t DISCON      :       1;

    uint8_t SESREQ      :       1;

    uint8_t VBUSERR     :       1;
};

struct __attribute__((packed)) USBIED_BITS {

    uint8_t SUSPEND     :       1;

    uint8_t RESUME      :       1;

    uint8_t RESET       :       1;

    uint8_t SOF         :       1;

    uint8_t RSVRD1      :       1;

    uint8_t DISCON      :       1;

    uint8_t RSVRD2      :       2;
};


union __attribute__((packed)) USBIE_REG {
    uint8_t    all;

    struct      USBIEH_BITS bitH;

    struct      USBIED_BITS bitD;
};


/*
 * USB Frame Value Register (USBFRAME), (Page 1480 TRM)
 */
struct __attribute__((packed)) USBFRAME_BITS {
    uint16_t FRAME      :       11;

    uint16_t RSVRD       :       5;
};

union __attribute__((packed)) USBFRAME_REG {
    uint16_t    all;

    struct      USBFRAME_BITS bit;
};


/*
 * USB Endpoint Index Register (USBEPIDX), (Page 1480 TRM)
 */
struct __attribute__((packed)) USBEPIDX_BITS {
    uint8_t EPIDX       :       4;

    uint8_t RSVRD       :       4;
};

union __attribute__((packed)) USBEPIDX_REG {
    uint8_t    all;

    struct      USBEPIDX_BITS bit;
};


/*
 * USB Test Mode Register (USBTEST), (Page 1481 TRM)
 */
struct __attribute__((packed)) USBTEST_BITS {
    uint8_t RSVRD       :       5;

    uint8_t FORCEFS     :       1;

    uint8_t FIFOACC     :       1;

    uint8_t FORCEH      :       1;
};

union __attribute__((packed)) USBTEST_REG {
    uint8_t    all;

    struct      USBTEST_BITS bit;
};




/*
 * USB FIFO Endpoint n Register (USBFIFO[n]), (Page 1483 TRM)
 */
struct __attribute__((packed)) USBFIFO_BITS {
    uint32_t EPDATA     :       32;
};

union __attribute__((packed)) USBFIFO_REG {
    uint32_t    all;

    struct      USBFIFO_BITS bit;
};


/*
 * USB Device Control Register (USBDEVCTL), (Page 1484 TRM), HOST
 */
struct __attribute__((packed)) USBDEVCTL_BITS {
    uint8_t SESSION     :       1;

    uint8_t HOSTREQ     :       1;

    uint8_t HOSTMODE    :       1;

    uint8_t VBUS        :       2;

    uint8_t LSDEV       :       1;

    uint8_t FSDEV       :       1;

    uint8_t DEV         :       1;
};

union __attribute__((packed)) USBDEVCTL_REG {
    uint8_t    all;

    struct      USBDEVCTL_BITS bit;
};


/*
 * USB Transmit Dynamic FIFO Sizing Register (USBTXFIFOSZ), (Page 1486 TRM), HOST
 */
struct __attribute__((packed)) USBTXFIFOSZ_BITS {
    uint8_t SZ          :       4;

    uint8_t DPB         :       1;

    uint8_t RSVRD       :       3;
};

union __attribute__((packed)) USBTXFIFOSZ_REG {
    uint8_t    all;

    struct      USBTXFIFOSZ_BITS bit;
};


/*
 * USB Receive Dynamic FIFO Sizing Register (USBRXFIFOSZ), (Page 1487 TRM), HOST
 */
struct __attribute__((packed)) USBRXFIFOSZ_BITS {
    uint8_t SZ          :       4;

    uint8_t DPB         :       1;

    uint8_t RSVRD       :       3;
};

union __attribute__((packed)) USBRXFIFOSZ_REG {
    uint8_t    all;

    struct      USBRXFIFOSZ_BITS bit;
};


/*
 * USB Transmit FIFO Start Address Register (USBTXFIFOADD), (Page 1488 TRM), HOST
 */
struct __attribute__((packed)) USBTXFIFOADD_BITS {
    uint16_t ADDR       :       9;

    uint16_t RSVRD      :       7;
};

union __attribute__((packed)) USBTXFIFOADD_REG {
    uint16_t    all;

    struct      USBTXFIFOADD_BITS bit;
};


/*
 * USB Receive FIFO Start Address Register (USBRXFIFOADD), (Page 1489 TRM), HOST
 */
struct __attribute__((packed)) USBRXFIFOADD_BITS {
    uint16_t ADDR       :       9;

    uint16_t RSVRD      :       7;
};

union __attribute__((packed)) USBRXFIFOADD_REG {
    uint16_t    all;

    struct      USBRXFIFOADD_BITS bit;
};


/*
 * USB Connect Timing Register (USBCONTIM), (Page 1490 TRM), HOST
 */
struct __attribute__((packed)) USBCONTIM_BITS {
    uint8_t WTID        :       4;

    uint8_t WTCON       :       4;
};

union __attribute__((packed)) USBCONTIM_REG {
    uint16_t    all;

    struct      USBCONTIM_BITS bit;
};


/*
 * USB OTG VBUS Pulse Timing Register (USBVPLEN), (Page 1490 TRM), HOST
 */
struct __attribute__((packed)) USBVPLEN_BITS {
    uint8_t VPLEN       :       8;
};

union __attribute__((packed)) USBVPLEN_REG {
    uint8_t     all;

    struct      USBVPLEN_BITS bit;
};


/*
 * USB Full-Speed Last Transaction to End of Frame Timing Register (USBFSEOF), (Page 1491 TRM), HOST
 */
struct __attribute__((packed)) USBFSEOF_BITS {
    uint8_t FSEOFG      :       8;
};

union __attribute__((packed)) USBFSEOF_REG {
    uint8_t     all;

    struct      USBFSEOF_BITS bit;
};


/*
 * USB Low-Speed Last Transaction to End of Frame Timing Register (USBLSEOF), (Page 1491 TRM), HOST
 */
union __attribute__((packed)) USBLSEOF_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBLSEOF_BITS {
        uint8_t LSEOFG      :       8;
    } bit;
};


/*
 * USB Transmit Functional Address Endpoint n Registers (USBTXFUNCADDR), (Page 1492 TRM), HOST
 */
union __attribute__((packed)) USBTXFUNCADDR_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXFUNCADDR_BITS {
        uint8_t ADDR        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Transmit Hub Address Endpoint n Registers (USBTXHUBADDR), (Page 1493 TRM), HOST
 */
union __attribute__((packed)) USBTXHUBADDR_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXHUBADDR_BITS {
        uint8_t ADDR        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Transmit Hub Port Endpoint n Registers (USBTXHUBPORT), (Page 1494 TRM), HOST
 */
union __attribute__((packed)) USBTXHUBPORT_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXHUBPORT_BITS {
        uint8_t PORT        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Receive Functional Address Endpoint n Registers (USBRXFUNCADDR), (Page 1495 TRM), HOST
 */
union __attribute__((packed)) USBRXFUNCADDR_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXFUNCADDR_BITS {
        uint8_t ADDR        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Receive Hub Address Endpoint n Registers (USBRXHUBADDR), (Page 1496 TRM), HOST
 */
union __attribute__((packed)) USBRXHUBADDR_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXHUBADDR_BITS {
        uint8_t ADDR        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Receive Hub Port Endpoint n Registers (USBRXHUBPORT), (Page 1497 TRM), HOST
 */
union __attribute__((packed)) USBRXHUBPORT_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXHUBPORT_BITS {
        uint8_t PORT        :       7;

        uint8_t RSVRD       :       1;
    } bit;
};


/*
 * USB Control and Status Endpoint 0 Low Register (USBCSRL0), (Page 1499 TRM)
 */
union __attribute__((packed)) USBCSRL0_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBCSRLH0_BITS {
        uint8_t RXRDY       :       1;

        uint8_t TXRDY       :       1;

        uint8_t STALLED     :       1;

        uint8_t SETUP       :       1;

        uint8_t ERROR       :       1;

        uint8_t REQPKT      :       1;

        uint8_t STATUS      :       1;

        uint8_t NAKTO       :       1;
    } bitH;

    struct __attribute__((packed)) USBCSRLD0_BITS {
        uint8_t RXRDY       :       1;

        uint8_t TXRDY       :       1;

        uint8_t STALLED     :       1;

        uint8_t DATAEND     :       1;

        uint8_t SETEND      :       1;

        uint8_t STALL       :       1;

        uint8_t RXRDYC      :       1;

        uint8_t SETENDC     :       1;
    } bitD;
};


/*
 * USB Control and Status Endpoint 0 High Register (USBCSRH0), (Page 1500 TRM)
 */
union __attribute__((packed)) USBCSRH0_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBCSRHH0_BITS {
        uint8_t FLUSH       :       1;

        uint8_t DT          :       1;

        uint8_t DTWE        :       1;

        uint8_t RSVRD       :       5;

    } bitH;

    struct __attribute__((packed)) USBCSRHD0_BITS {
        uint8_t FLUSH       :       1;

        uint8_t RSVRD       :       7;

    } bitD;
};


/*
 * USB Receive Byte Count Endpoint 0 Register (USBCOUNT0), (Page 1502 TRM)
 */
union __attribute__((packed)) USBCOUNT0_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBCOUNT0_BITS {
        uint8_t COUNT       :       7;

        uint8_t RSVRD       :       1;

    } bit;
};


/*
 * USB Type Endpoint 0 Register (USBTYPE0), (Page 1502 TRM), HOST
 */
union __attribute__((packed)) USBTYPE0_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTYPE0_BITS {
        uint8_t RSVRD       :       6;

        uint8_t SPEED       :       2;

    } bit;
};


/*
 * USB NAK Limit Register (USBNAKLMT), (Page 1503 TRM), HOST
 */
union __attribute__((packed)) USBNAKLMT_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBNAKLMT_BITS {
        uint8_t NAKLMT      :       5;

        uint8_t RSVRD       :       3;

    } bit;
};


/*
 * USB Maximum Transmit Data Endpoint n Registers (USBTXMAXP), (Page 1498 TRM)
 */
union __attribute__((packed)) USBTXMAXP_REG {
    uint16_t     all;

    struct __attribute__((packed)) USBTXMAXP_BITS {
        uint16_t MAXLOAD    :       11;

        uint16_t RSVRD      :       5;

    } bit;
};


/*
 * USB Transmit Control and Status Endpoint n Low Register (USBTXCSRL), (Page 1504 TRM)
 */
union __attribute__((packed)) USBTXCSRL_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXCSRLH_BITS {
        uint8_t TXRDY       :       1;

        uint8_t FIFONE      :       1;

        uint8_t ERROR       :       1;

        uint8_t FLUSH       :       1;

        uint8_t SETUP       :       1;

        uint8_t STALLED     :       1;

        uint8_t CLRDT       :       1;

        uint8_t NAKTO       :       1;

    } bitH;

    struct __attribute__((packed)) USBTXCSRLD_BITS {
        uint8_t TXRDY       :       1;

        uint8_t FIFONE      :       1;

        uint8_t UNDRN       :       1;

        uint8_t FLUSH       :       1;

        uint8_t STALL       :       1;

        uint8_t STALLED     :       1;

        uint8_t CLRDT       :       1;

        uint8_t RSVRD       :       1;

    } bitD;
};


/*
 * USB Transmit Control and Status Endpoint n High Register (USBTXCSRH), (Page 1504 TRM)
 */
union __attribute__((packed)) USBTXCSRH_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXCSRHH_BITS {
        uint8_t DT          :       1;

        uint8_t DTWE        :       1;

        uint8_t DMAMOD      :       1;

        uint8_t FDT         :       1;

        uint8_t DMAEN       :       1;

        uint8_t MODE        :       1;

        uint8_t RSVRD       :       1;

        uint8_t AUTOSET     :       1;

    } bitH;

    struct __attribute__((packed)) USBTXCSRHD_BITS {
        uint8_t RSVRD       :       2;

        uint8_t DMAMOD      :       1;

        uint8_t FDT         :       1;

        uint8_t DMAEN       :       1;

        uint8_t MODE        :       1;

        uint8_t ISO         :       1;

        uint8_t AUTOSET     :       1;

    } bitD;
};


/*
 * USB Maximum Receive Data Endpoint n Registers (USBRXMAXP), (Page 1498 TRM)
 */
union __attribute__((packed)) USBRXMAXP_REG {
    uint16_t     all;

    struct __attribute__((packed)) USBRXMAXP_BITS {
        uint16_t MAXLOAD    :       11;

        uint16_t RSVRD      :       5;

    } bit;
};


/*
 * USB Receive Control and Status Endpoint n Low Register (USBRXCSRL), (Page 1510 TRM)
 */
union __attribute__((packed)) USBRXCSRL_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXCSRLH_BITS {
        uint8_t RXRDY       :       1;

        uint8_t FULL        :       1;

        uint8_t ERROR       :       1;

        uint8_t DATAERR_NAKTO       :       1;

        uint8_t FLUSH       :       1;

        uint8_t REQPKT      :       1;

        uint8_t STALLED     :       1;

        uint8_t CLRDT       :       1;

    } bitH;

    struct __attribute__((packed)) USBRXCSRLD_BITS {
        uint8_t RXRDY       :       1;

        uint8_t FULL        :       1;

        uint8_t OVER        :       1;

        uint8_t DATAERR     :       1;

        uint8_t FLUSH       :       1;

        uint8_t STALL       :       1;

        uint8_t STALLED     :       1;

        uint8_t CLRDT       :       1;

    } bitD;
};


/*
 * USB Receive Control and Status Endpoint n High Register (USBRXCSRH), (Page 1513 TRM)
 */
union __attribute__((packed)) USBRXCSRH_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXCSRHH_BITS {
        uint8_t RSVRD       :       1;

        uint8_t DT          :       1;

        uint8_t DTWE        :       1;

        uint8_t DMAMOD      :       1;

        uint8_t PIDERR      :       1;

        uint8_t DMAEN       :       1;

        uint8_t AUTORQ      :       1;

        uint8_t AUTOCL      :       1;

    } bitH;

    struct __attribute__((packed)) USBRXCSRHD_BITS {
        uint8_t RSVRD       :       3;

        uint8_t DMAMOD      :       1;

        uint8_t DISNYET_PIDERR        :       1;

        uint8_t DMAEN       :       1;

        uint8_t ISO         :       1;

        uint8_t AUTOCL      :       1;

    } bitD;
};


/*
 * USB Receive Byte Count Endpoint n Registers (USBRXCOUNT), (Page 1515 TRM)
 */
union __attribute__((packed)) USBRXCOUNT_REG {
    uint16_t     all;

    struct __attribute__((packed)) USBRXCOUNT_BITS {
        uint16_t COUNT      :       13;

        uint16_t RSVRD      :       3;

    } bit;
};


/*
 * USB Host Transmit Configure Type Endpoint n Register (USBTXTYPE), (Page 1515 TRM), HOST
 */
union __attribute__((packed)) USBTXTYPE_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXTYPE_BITS {
        uint8_t TEP         :       4;

        uint8_t PROTO       :       2;

        uint8_t SPEED       :       2;

    } bit;
};


/*
 * USB Host Transmit Interval Endpoint n Register (USBTXINTERVAL), (Page 1517 TRM), HOST
 */
union __attribute__((packed)) USBTXINTERVAL_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBTXINTERVAL_BITS {
        uint8_t TXPOLL      :       8;
    } bit;
};


/*
 * USB Host Configure Receive Type Endpoint n Register (USBRXTYPE), (Page 1518 TRM), HOST
 */
union __attribute__((packed)) USBRXTYPE_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXTYPE_BITS {
        uint8_t TEP         :       4;

        uint8_t PROTO       :       2;

        uint8_t SPEED       :       2;

    } bit;
};


/*
 * USB Host Receive Polling Interval Endpoint n Register (USBRXINTERVAL), (Page 1517 TRM), HOST
 */
union __attribute__((packed)) USBRXINTERVAL_REG {
    uint8_t     all;

    struct __attribute__((packed)) USBRXINTERVAL_BITS {
        uint8_t RXPOLL      :       8;
    } bit;
};


/*
 * USB Request Packet Count in Block Transfer Endpoint n Registers (USBRQPKTCOUNT), (Page 1520 TRM)
 */
union __attribute__((packed)) USBRQPKTCOUNT_REG {
    uint32_t     all;

    struct __attribute__((packed)) USBRQPKTCOUNT_BITS {
        uint32_t COUNT      :       13;

        uint32_t RSVRD      :       19;

    } bit;
};





/*
 * USB Register MAP Page 1457 TRM
 */
struct __attribute__((packed)) USB_REGS {
    union USBFADDR_REG          USBFADDR;

    union USBPOWER_REG          USBPOWER;

    union USBTXIS_REG           USBTXIS;

    union USBRXIS_REG           USBRXIS;

    union USBTXIE_REG           USBTXIE;

    union USBRXIE_REG           USBRXIE;

    union USBIS_REG             USBIS;

    union USBIE_REG             USBIE;

    union USBFRAME_REG          USBFRAME;

    union USBEPIDX_REG          USBEPIDX;

    union USBTEST_REG           USBTEST;

    uint32_t RSVRD1[ ( 0x20 - 0x10 ) >> 2 ];

    union USBFIFO_REG           USBFIFO0;

    union USBFIFO_REG           USBFIFO1;

    union USBFIFO_REG           USBFIFO2;

    union USBFIFO_REG           USBFIFO3;

    union USBFIFO_REG           USBFIFO4;

    union USBFIFO_REG           USBFIFO5;

    union USBFIFO_REG           USBFIFO6;

    union USBFIFO_REG           USBFIFO7;

    union USBFIFO_REG           USBFIFO8;

    union USBFIFO_REG           USBFIFO9;

    union USBFIFO_REG           USBFIFO10;

    union USBFIFO_REG           USBFIFO11;

    union USBFIFO_REG           USBFIFO12;

    union USBFIFO_REG           USBFIFO13;

    union USBFIFO_REG           USBFIFO14;

    union USBFIFO_REG           USBFIFO15;

    union USBDEVCTL_REG         USBDEVCTL;

    uint8_t RSVRD2;

    union USBTXFIFOSZ_REG       USBTXFIFOSZ;

    union USBRXFIFOSZ_REG       USBRXFIFOSZ;

    union USBTXFIFOADD_REG      USBTXFIFOADD;

    union USBRXFIFOADD_REG      USBRXFIFOADD;

    uint8_t RSVRD3[ ( 0x7A - 0x68 ) ];

    union USBCONTIM_REG         USBCONTIM;

    union USBVPLEN_REG          USBVPLEN;

    uint8_t RSVRD4;

    union USBFSEOF_REG          USBFSEOF;           // 0x07D

    uint8_t RSVRD6;

    union USBLSEOF_REG          USBLSEOF;           // 0x07E

    union USBTXFUNCADDR_REG     USBTXFUNCADDR0;     // 0x080

    uint8_t RSVRD7;

    union USBTXHUBADDR_REG      USBTXHUBADDR0;      // 0x082

    union USBTXHUBPORT_REG      USBTXHUBPORT0;      // 0x083

    uint32_t RSVRD8;

    union USBTXFUNCADDR_REG     USBTXFUNCADDR1;     // 0x088

    uint8_t RSVRD9;

    union USBTXHUBADDR_REG      USBTXHUBADDR1;      // 0x08A

    union USBTXHUBPORT_REG      USBTXHUBPORT1;      // 0x08B

    union USBRXFUNCADDR_REG     USBRXFUNCADDR1;     // 0x08C

    uint8_t RSVRD10;

    union USBRXHUBADDR_REG      USBRXHUBADDR1;      // 0x08E

    union USBRXHUBPORT_REG      USBRXHUBPORT1;      // 0x08F

    union USBTXFUNCADDR_REG     USBTXFUNCADDR2;     // 0x090

    uint8_t RSVRD11;

    union USBTXHUBADDR_REG      USBTXHUBADDR2;      // 0x092

    union USBTXHUBPORT_REG      USBTXHUBPORT2;      // 0x093

    union USBRXFUNCADDR_REG     USBRXFUNCADDR2;     // 0x094

    uint8_t RSVRD12;

    union USBRXHUBADDR_REG      USBRXHUBADDR2;      // 0x096

    union USBRXHUBPORT_REG      USBRXHUBPORT2;      // 0x097

    union USBTXFUNCADDR_REG     USBTXFUNCADDR3;     // 0x098

    uint8_t RSVRD13;

    union USBTXHUBADDR_REG      USBTXHUBADDR3;      // 0x09A

    union USBTXHUBPORT_REG      USBTXHUBPORT3;      // 0x09B

    union USBRXFUNCADDR_REG     USBRXFUNCADDR3;     // 0x09C

    uint8_t RSVRD14;

    union USBRXHUBADDR_REG      USBRXHUBADDR3;      // 0x09E

    union USBRXHUBPORT_REG      USBRXHUBPORT3;      // 0x09F

    union USBTXFUNCADDR_REG     USBTXFUNCADDR4;     // 0x0A0

    uint8_t RSVRD15;

    union USBTXHUBADDR_REG      USBTXHUBADDR4;      // 0x092

    union USBTXHUBPORT_REG      USBTXHUBPORT4;      // 0x0A3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR4;     // 0x0A4

    uint8_t RSVRD16;

    union USBRXHUBADDR_REG      USBRXHUBADDR4;      // 0x0A6

    union USBRXHUBPORT_REG      USBRXHUBPORT4;      // 0x0A7

    union USBTXFUNCADDR_REG     USBTXFUNCADDR5;     // 0x0A8

    uint8_t RSVRD17;

    union USBTXHUBADDR_REG      USBTXHUBADDR5;      // 0x0AA

    union USBTXHUBPORT_REG      USBTXHUBPORT5;      // 0x0AB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR5;     // 0x0AC

    uint8_t RSVRD18;

    union USBRXHUBADDR_REG      USBRXHUBADDR5;      // 0x0AE

    union USBRXHUBPORT_REG      USBRXHUBPORT5;      // 0x0AF

    union USBTXFUNCADDR_REG     USBTXFUNCADDR6;     // 0x0B0

    uint8_t RSVRD19;

    union USBTXHUBADDR_REG      USBTXHUBADDR6;      // 0x0B2

    union USBTXHUBPORT_REG      USBTXHUBPORT6;      // 0x0B3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR6;     // 0x0B4

    uint8_t RSVRD20;

    union USBRXHUBADDR_REG      USBRXHUBADDR6;      // 0x0B6

    union USBRXHUBPORT_REG      USBRXHUBPORT6;      // 0x0B7

    union USBTXFUNCADDR_REG     USBTXFUNCADDR7;     // 0x0B8

    uint8_t RSVRD21;

    union USBTXHUBADDR_REG      USBTXHUBADDR7;      // 0x0BA

    union USBTXHUBPORT_REG      USBTXHUBPORT7;      // 0x0BB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR7;     // 0x0BC

    uint8_t RSVRD22;

    union USBRXHUBADDR_REG      USBRXHUBADDR7;      // 0x0BE

    union USBRXHUBPORT_REG      USBRXHUBPORT7;      // 0x0BF

    union USBTXFUNCADDR_REG     USBTXFUNCADDR8;     // 0x0C0

    uint8_t RSVRD23;

    union USBTXHUBADDR_REG      USBTXHUBADDR8;      // 0x0C2

    union USBTXHUBPORT_REG      USBTXHUBPORT8;      // 0x0C3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR8;     // 0x0C4

    uint8_t RSVRD24;

    union USBRXHUBADDR_REG      USBRXHUBADDR8;      // 0x0C6

    union USBRXHUBPORT_REG      USBRXHUBPORT8;      // 0x0C7

    union USBTXFUNCADDR_REG     USBTXFUNCADDR9;     // 0x0C8

    uint8_t RSVRD25;

    union USBTXHUBADDR_REG      USBTXHUBADDR9;      // 0x0CA

    union USBTXHUBPORT_REG      USBTXHUBPORT9;      // 0x0CB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR9;     // 0x0CC

    uint8_t RSVRD26;

    union USBRXHUBADDR_REG      USBRXHUBADDR9;      // 0x0CE

    union USBRXHUBPORT_REG      USBRXHUBPORT9;      // 0x0CF

    union USBTXFUNCADDR_REG     USBTXFUNCADDR10;    // 0x0D0

    uint8_t RSVRD27;

    union USBTXHUBADDR_REG      USBTXHUBADDR10;     // 0x0D2

    union USBTXHUBPORT_REG      USBTXHUBPORT10;     // 0x0D3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR10;    // 0x0D4

    uint8_t RSVRD28;

    union USBRXHUBADDR_REG       USBRXHUBADDR10;     // 0x0D6

    union USBRXHUBPORT_REG       USBRXHUBPORT10;     // 0x0D7

    union USBTXFUNCADDR_REG      USBTXFUNCADDR11;    // 0x0D8

    uint8_t RSVRD29;

    union USBTXHUBADDR_REG      USBTXHUBADDR11;     // 0x0DA

    union USBTXHUBPORT_REG      USBTXHUBPORT11;     // 0x0DB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR11;    // 0x0DC

    uint8_t RSVRD30;

    union USBRXHUBADDR_REG      USBRXHUBADDR11;     // 0x0DE

    union USBRXHUBPORT_REG      USBRXHUBPORT11;     // 0x0DF

    union USBTXFUNCADDR_REG     USBTXFUNCADDR12;    // 0x0E0

    uint8_t RSVRD31;

    union USBTXHUBADDR_REG      USBTXHUBADDR12;     // 0x0E2

    union USBTXHUBPORT_REG      USBTXHUBPORT12;     // 0x0E3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR12;    // 0x0E4

    uint8_t RSVRD32;

    union USBRXHUBADDR_REG      USBRXHUBADDR12;     // 0x0E6

    union USBRXHUBPORT_REG      USBRXHUBPORT12;     // 0x0E7

    union USBTXFUNCADDR_REG     USBTXFUNCADDR13;    // 0x0E8

    uint8_t RSVRD33;

    union USBTXHUBADDR_REG      USBTXHUBADDR13;     // 0x0EA

    union USBTXHUBPORT_REG      USBTXHUBPORT13;     // 0x0EB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR13;    // 0x0EC

    uint8_t RSVRD34;

    union USBRXHUBADDR_REG      USBRXHUBADDR13;     // 0x0EE

    union USBRXHUBPORT_REG      USBRXHUBPORT13;     // 0x0EF

    union USBTXFUNCADDR_REG     USBTXFUNCADDR14;    // 0x0F0

    uint8_t RSVRD35;

    union USBTXHUBADDR_REG      USBTXHUBADDR14;     // 0x0F2

    union USBTXHUBPORT_REG      USBTXHUBPORT14;     // 0x0F3

    union USBRXFUNCADDR_REG     USBRXFUNCADDR14;    // 0x0F4

    uint8_t RSVRD36;

    union USBRXHUBADDR_REG      USBRXHUBADDR14;     // 0x0F6

    union USBRXHUBPORT_REG      USBRXHUBPORT14;     // 0x0F7

    union USBTXFUNCADDR_REG     USBTXFUNCADDR15;    // 0x0F8

    uint8_t RSVRD37;

    union USBTXHUBADDR_REG      USBTXHUBADDR15;     // 0x0FA

    union USBTXHUBPORT_REG      USBTXHUBPORT15;     // 0x0FB

    union USBRXFUNCADDR_REG     USBRXFUNCADDR15;    // 0x0FC

    uint8_t RSVRD38;

    union USBRXHUBADDR_REG      USBRXHUBADDR15;     // 0x0FE

    union USBRXHUBPORT_REG      USBRXHUBPORT15;     // 0x0FF

    uint8_t RSVRD39;

    union USBCSRL0_REG          USBCSRL0;           // 0x102

    union USBCSRH0_REG          USBCSRH0;           // 0x103

    uint32_t RSVRD40;

    union USBCOUNT0_REG         USBCOUNT0;          // 0x108

    uint8_t RSVRD41;

    union USBTYPE0_REG          USBTYPE0;           // 0x10A

    union USBNAKLMT_REG         USBNAKLMT;          // 0x10B

    uint32_t RSVRD42;

    union USBTXMAXP_REG         USBTXMAXP1;         // 0x110

    union USBTXCSRL_REG         USBTXCSRL1;         // 0x112

    union USBTXCSRH_REG         USBTXCSRH1;         // 0x113

    union USBRXMAXP_REG         USBRXMAXP1;         // 0x114

    union USBRXCSRL_REG         USBRXCSRL1;         // 0x116

    union USBRXCSRH_REG         USBRXCSRH1;         // 0x117

    union USBRXCOUNT_REG        USBRXCOUNT1;        // 0x118

    union USBTXTYPE_REG         USBTXTYPE1;         // 0x11A

    union USBTXINTERVAL_REG     USBTXINTERVAL1;     // 0x11B

    union USBRXTYPE_REG         USBRXTYPE1;         // 0x11C

    union USBRXINTERVAL_REG     USBRXINTERVAL1;     // 0x11D

    uint16_t RSVRD43;

    union USBTXMAXP_REG         USBTXMAXP2;         // 0x120

    union USBTXCSRL_REG         USBTXCSRL2;         // 0x122

    union USBTXCSRH_REG         USBTXCSRH2;         // 0x123

    union USBRXMAXP_REG         USBRXMAXP2;         // 0x124

    union USBRXCSRL_REG         USBRXCSRL2;         // 0x126

    union USBRXCSRH_REG         USBRXCSRH2;         // 0x127

    union USBRXCOUNT_REG        USBRXCOUNT2;        // 0x128

    union USBTXTYPE_REG         USBTXTYPE2;         // 0x12A

    union USBTXINTERVAL_REG     USBTXINTERVAL2;     // 0x12B

    union USBRXTYPE_REG         USBRXTYPE2;         // 0x12C

    union USBRXINTERVAL_REG     USBRXINTERVAL2;     // 0x12D

    uint16_t RSVRD44;

    union USBTXMAXP_REG         USBTXMAXP3;         // 0x130

    union USBTXCSRL_REG         USBTXCSRL3;         // 0x132

    union USBTXCSRH_REG         USBTXCSRH3;         // 0x133

    union USBRXMAXP_REG         USBRXMAXP3;         // 0x134

    union USBRXCSRL_REG         USBRXCSRL3;         // 0x136

    union USBRXCSRH_REG         USBRXCSRH3;         // 0x137

    union USBRXCOUNT_REG        USBRXCOUNT3;        // 0x138

    union USBTXTYPE_REG         USBTXTYPE3;         // 0x13A

    union USBTXINTERVAL_REG     USBTXINTERVAL3;     // 0x13B

    union USBRXTYPE_REG         USBRXTYPE3;         // 0x13C

    union USBRXINTERVAL_REG     USBRXINTERVAL3;     // 0x13D

    uint16_t RSVRD45;

    union USBTXMAXP_REG         USBTXMAXP4;         // 0x140

    union USBTXCSRL_REG         USBTXCSRL4;         // 0x142

    union USBTXCSRH_REG         USBTXCSRH4;         // 0x143

    union USBRXMAXP_REG         USBRXMAXP4;         // 0x144

    union USBRXCSRL_REG         USBRXCSRL4;         // 0x146

    union USBRXCSRH_REG         USBRXCSRH4;         // 0x147

    union USBRXCOUNT_REG        USBRXCOUNT4;        // 0x148

    union USBTXTYPE_REG         USBTXTYPE4;         // 0x14A

    union USBTXINTERVAL_REG     USBTXINTERVAL4;     // 0x14B

    union USBRXTYPE_REG         USBRXTYPE4;         // 0x14C

    union USBRXINTERVAL_REG     USBRXINTERVAL4;     // 0x14D

    uint16_t RSVRD46;

    union USBTXMAXP_REG         USBTXMAXP5;         // 0x150

    union USBTXCSRL_REG         USBTXCSRL5;         // 0x152

    union USBTXCSRH_REG         USBTXCSRH5;         // 0x153

    union USBRXMAXP_REG         USBRXMAXP5;         // 0x154

    union USBRXCSRL_REG         USBRXCSRL5;         // 0x156

    union USBRXCSRH_REG         USBRXCSRH5;         // 0x157

    union USBRXCOUNT_REG        USBRXCOUNT5;        // 0x158

    union USBTXTYPE_REG         USBTXTYPE5;         // 0x15A

    union USBTXINTERVAL_REG     USBTXINTERVAL5;     // 0x15B

    union USBRXTYPE_REG         USBRXTYPE5;         // 0x15C

    union USBRXINTERVAL_REG     USBRXINTERVAL5;     // 0x15D

    uint16_t RSVRD47;

    union USBTXMAXP_REG         USBTXMAXP6;         // 0x160

    union USBTXCSRL_REG         USBTXCSRL6;         // 0x162

    union USBTXCSRH_REG         USBTXCSRH6;         // 0x163

    union USBRXMAXP_REG         USBRXMAXP6;         // 0x164

    union USBRXCSRL_REG         USBRXCSRL6;         // 0x166

    union USBRXCSRH_REG         USBRXCSRH6;         // 0x167

    union USBRXCOUNT_REG        USBRXCOUNT6;        // 0x168

    union USBTXTYPE_REG         USBTXTYPE6;         // 0x16A

    union USBTXINTERVAL_REG     USBTXINTERVAL6;     // 0x16B

    union USBRXTYPE_REG         USBRXTYPE6;         // 0x16C

    union USBRXINTERVAL_REG     USBRXINTERVAL6;     // 0x16D

    uint16_t RSVRD48;

    union USBTXMAXP_REG         USBTXMAXP7;         // 0x170

    union USBTXCSRL_REG         USBTXCSRL7;         // 0x172

    union USBTXCSRH_REG         USBTXCSRH7;         // 0x173

    union USBRXMAXP_REG         USBRXMAXP7;         // 0x174

    union USBRXCSRL_REG         USBRXCSRL7;         // 0x176

    union USBRXCSRH_REG         USBRXCSRH7;         // 0x177

    union USBRXCOUNT_REG        USBRXCOUNT7;        // 0x178

    union USBTXTYPE_REG         USBTXTYPE7;         // 0x17A

    union USBTXINTERVAL_REG     USBTXINTERVAL7;     // 0x17B

    union USBRXTYPE_REG         USBRXTYPE7;         // 0x17C

    union USBRXINTERVAL_REG     USBRXINTERVAL7;     // 0x17D

    uint16_t RSVRD49;

    union USBTXMAXP_REG         USBTXMAXP8;         // 0x180

    union USBTXCSRL_REG         USBTXCSRL8;         // 0x182

    union USBTXCSRH_REG         USBTXCSRH8;         // 0x183

    union USBRXMAXP_REG         USBRXMAXP8;         // 0x184

    union USBRXCSRL_REG         USBRXCSRL8;         // 0x186

    union USBRXCSRH_REG         USBRXCSRH8;         // 0x187

    union USBRXCOUNT_REG        USBRXCOUNT8;        // 0x188

    union USBTXTYPE_REG         USBTXTYPE8;         // 0x18A

    union USBTXINTERVAL_REG     USBTXINTERVAL8;     // 0x18B

    union USBRXTYPE_REG         USBRXTYPE8;         // 0x18C

    union USBRXINTERVAL_REG     USBRXINTERVAL8;     // 0x18D

    uint16_t RSVRD50;

    union USBTXMAXP_REG         USBTXMAXP9;         // 0x190

    union USBTXCSRL_REG         USBTXCSRL9;         // 0x192

    union USBTXCSRH_REG         USBTXCSRH9;         // 0x193

    union USBRXMAXP_REG         USBRXMAXP9;         // 0x194

    union USBRXCSRL_REG         USBRXCSRL9;         // 0x196

    union USBRXCSRH_REG         USBRXCSRH9;         // 0x197

    union USBRXCOUNT_REG        USBRXCOUNT9;        // 0x198

    union USBTXTYPE_REG         USBTXTYPE9;         // 0x19A

    union USBTXINTERVAL_REG     USBTXINTERVAL9;     // 0x19B

    union USBRXTYPE_REG         USBRXTYPE9;         // 0x19C

    union USBRXINTERVAL_REG     USBRXINTERVAL9;     // 0x19D

    uint16_t RSVRD51;

    union USBTXMAXP_REG         USBTXMAXP10;        // 0x1A0

    union USBTXCSRL_REG         USBTXCSRL10;        // 0x1A2

    union USBTXCSRH_REG         USBTXCSRH10;        // 0x1A3

    union USBRXMAXP_REG         USBRXMAXP10;        // 0x1A4

    union USBRXCSRL_REG         USBRXCSRL10;        // 0x1A6

    union USBRXCSRH_REG         USBRXCSRH10;        // 0x1A7

    union USBRXCOUNT_REG        USBRXCOUNT10;       // 0x1A8

    union USBTXTYPE_REG         USBTXTYPE10;        // 0x1AA

    union USBTXINTERVAL_REG     USBTXINTERVAL10;    // 0x1AB

    union USBRXTYPE_REG         USBRXTYPE10;        // 0x1AC

    union USBRXINTERVAL_REG     USBRXINTERVAL10;    // 0x1AD

    uint16_t RSVRD52;

    union USBTXMAXP_REG         USBTXMAXP11;        // 0x1B0

    union USBTXCSRL_REG         USBTXCSRL11;        // 0x1B2

    union USBTXCSRH_REG         USBTXCSRH11;        // 0x1B3

    union USBRXMAXP_REG         USBRXMAXP11;        // 0x1B4

    union USBRXCSRL_REG         USBRXCSRL11;        // 0x1B6

    union USBRXCSRH_REG         USBRXCSRH11;        // 0x1B7

    union USBRXCOUNT_REG        USBRXCOUNT11;       // 0x1B8

    union USBTXTYPE_REG         USBTXTYPE11;        // 0x1BA

    union USBTXINTERVAL_REG     USBTXINTERVAL11;    // 0x1BB

    union USBRXTYPE_REG         USBRXTYPE11;        // 0x1BC

    union USBRXINTERVAL_REG     USBRXINTERVAL11;    // 0x1BD

    uint16_t RSVRD53;

    union USBTXMAXP_REG         USBTXMAXP12;        // 0x1C0

    union USBTXCSRL_REG         USBTXCSRL12;        // 0x1C2

    union USBTXCSRH_REG         USBTXCSRH12;        // 0x1C3

    union USBRXMAXP_REG         USBRXMAXP12;        // 0x1C4

    union USBRXCSRL_REG         USBRXCSRL12;        // 0x1C6

    union USBRXCSRH_REG         USBRXCSRH12;        // 0x1C7

    union USBRXCOUNT_REG        USBRXCOUNT12;       // 0x1C8

    union USBTXTYPE_REG         USBTXTYPE12;        // 0x1CA

    union USBTXINTERVAL_REG     USBTXINTERVAL12;    // 0x1CB

    union USBRXTYPE_REG         USBRXTYPE12;        // 0x1CC

    union USBRXINTERVAL_REG     USBRXINTERVAL12;    // 0x1CD

    uint16_t RSVRD54;

    union USBTXMAXP_REG         USBTXMAXP13;        // 0x1D0

    union USBTXCSRL_REG         USBTXCSRL13;        // 0x1D2

    union USBTXCSRH_REG         USBTXCSRH13;        // 0x1D3

    union USBRXMAXP_REG         USBRXMAXP13;        // 0x1D4

    union USBRXCSRL_REG         USBRXCSRL13;        // 0x1D6

    union USBRXCSRH_REG         USBRXCSRH13;        // 0x1D7

    union USBRXCOUNT_REG        USBRXCOUNT13;       // 0x1D8

    union USBTXTYPE_REG         USBTXTYPE13;        // 0x1DA

    union USBTXINTERVAL_REG     USBTXINTERVAL13;    // 0x1DB

    union USBRXTYPE_REG         USBRXTYPE13;        // 0x1DC

    union USBRXINTERVAL_REG     USBRXINTERVAL13;    // 0x1DD

    uint16_t RSVRD55;

    union USBTXMAXP_REG         USBTXMAXP14;        // 0x1E0

    union USBTXCSRL_REG         USBTXCSRL14;        // 0x1E2

    union USBTXCSRH_REG         USBTXCSRH14;        // 0x1E3

    union USBRXMAXP_REG         USBRXMAXP14;        // 0x1E4

    union USBRXCSRL_REG         USBRXCSRL14;        // 0x1E6

    union USBRXCSRH_REG         USBRXCSRH14;        // 0x1E7

    union USBRXCOUNT_REG        USBRXCOUNT14;       // 0x1E8

    union USBTXTYPE_REG         USBTXTYPE14;        // 0x1EA

    union USBTXINTERVAL_REG     USBTXINTERVAL14;    // 0x1EB

    union USBRXTYPE_REG         USBRXTYPE14;        // 0x1EC

    union USBRXINTERVAL_REG     USBRXINTERVAL14;    // 0x1ED

    uint16_t RSVRD56;

    union USBTXMAXP_REG         USBTXMAXP15;        // 0x1F0

    union USBTXCSRL_REG         USBTXCSRL15;        // 0x1F2

    union USBTXCSRH_REG         USBTXCSRH15;        // 0x1F3

    union USBRXMAXP_REG         USBRXMAXP15;        // 0x1F4

    union USBRXCSRL_REG         USBRXCSRL15;        // 0x1F6

    union USBRXCSRH_REG         USBRXCSRH15;        // 0x1F7

    union USBRXCOUNT_REG        USBRXCOUNT15;       // 0x1F8

    union USBTXTYPE_REG         USBTXTYPE15;        // 0x1FA

    union USBTXINTERVAL_REG     USBTXINTERVAL15;    // 0x1FB

    union USBRXTYPE_REG         USBRXTYPE15;        // 0x1FC

    union USBRXINTERVAL_REG     USBRXINTERVAL15;    // 0x1FD

    uint8_t RSVRD57[ ( 0x304 - 0x1FE ) ];

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT1;     // 0x304

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT2;     // 0x308

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT3;     // 0x30C

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT4;     // 0x310

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT5;     // 0x314

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT6;     // 0x318

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT7;     // 0x31C

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT8;     // 0x320

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT9;     // 0x324

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT10;    // 0x328

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT11;    // 0x32C

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT12;    // 0x330

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT13;    // 0x334

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT14;    // 0x338

    union USBRQPKTCOUNT_REG     USBRQPKTCOUNT15;    // 0x33C

};

extern volatile struct USB_REGS USB0Regs;

#ifdef __cplusplus
}
#endif  /* extern "C" */

#endif /* __F28M35H52C1_USBREGS_H__ */
