/*
 * File: clkcfg.c
 */

#include "../../F28M35H52C1M_headers/include/F28M35H52C1_Device.h"

#include "sysctl.h"

#include "clkcfg.h"

static void clckcfg_peripherial_clk_init( void );

static void clckcfg_peripherial_clk_init( void )
{
    // Enable clock supply for GPIOC
    SysCtlRegs.RCGC2.bit.GPIOC      = 1;

    SysCtlRegs.RCGC1.bit.TIMER0     = 1;
}

void clkcfg_init( void )
{
    uint32_t u32CfgTempWord;

    uint32_t u32MWRAllow;

    u32MWRAllow                     = M3MWRAllowCfgRegs.MWRALLOW.all;

    M3MWRAllowCfgRegs.MWRALLOW.all  = MWR_ALLOW_KEY;

    SysCtlRegs.RCGC0.bit.WDT0 = 0;
    SysCtlRegs.RCGC0.bit.WDT1 = 0;

    // Modify dividers to maximum
    ClkCfgRegs.M3SSDIVSEL.all       = M3SSDIVSEL_PLLCLK_DIV_4;

    SysCtlDelay( 15 );    /*delay some where around 50 clock cycles*/

    ClkCfgRegs.SYSDIVSEL.all        = C28_CLKIN_PLLCLK_DIV_8;

    SysCtlDelay( 15 );

#if( F28M35H52C1_CFG_SYSPLLEN_VAL )
    // First modify the PLL multipliers
    // Ensure the PLL is bypassed
    ClkCfgRegs.SYSPLLCTL.bit.SPLLCLKEN = 0;

    // Write requested value
    ClkCfgRegs.SYSPLLMULT.all = F28M35H52C1_CFG_SYSPLLMULT_VAL;

    // Enable the PLL
    // Turn on the PLL, but don't clock the processor off of it
    ClkCfgRegs.SYSPLLCTL.bit.SPLLEN = 1;

    // Wait for PLL to lock
    while(  ClkCfgRegs.SYSPLLSTS.bit.SYSPLLLOCKS == 0 );

    // Enable PLL clock to CPU
    ClkCfgRegs.SYSPLLCTL.bit.SPLLCLKEN = 1;
#else
    ClkCfgRegs.SYSPLLCTL.bit.SPLLCLKEN = 0;
#endif
    /*
     * Configure the M3SSCLK DIVIDER
     * Increase Frequency of operation in steps to avoid any VDD fluctuations
     */
    u32CfgTempWord = M3SSDIVSEL_PLLCLK_DIV_4;

    while( u32CfgTempWord != F28M35H52C1_CFG_M3SSDIVSEL_VAL )
    {
        u32CfgTempWord              -= 1;

        ClkCfgRegs.M3SSDIVSEL.all    = u32CfgTempWord;

        SysCtlDelay( 15 );
    }

    u32CfgTempWord = C28_CLKIN_PLLCLK_DIV_8;

    while( u32CfgTempWord != F28M35H52C1_CFG_M3SSDIVSEL_VAL )
    {
        u32CfgTempWord              -= 1;

        ClkCfgRegs.SYSDIVSEL.all     = u32CfgTempWord;

        SysCtlDelay( 15 );
    }

    ClkCfgRegs.XPLLCLKCFG.all       = F28M35H52C1_CFG_XPLLCLKCFG_VAL;

    ClkCfgRegs.CCLKOFF.all          = F28M35H52C1_CFG_CCLKOFF_VAL;

    clckcfg_peripherial_clk_init();

    M3MWRAllowCfgRegs.MWRALLOW.all  = u32MWRAllow;

    SysCtlDelay( 2000 );
}
