/*
 * File: gptm.c
 */

#include "../../F28M35H52C1M_headers/include/F28M35H52C1_Device.h"

#include "psp_utils.h"
#include "gptm.h"

#define GPTM0_TICK_sec                  ( 10 )

#define GPTM0_HALF_SECOND_sec           ( 500000 )


void Gptm0TAISR( void )
{
    volatile struct GPTM_REGS* pGPTMRegs;

    static uint32_t u32Val = 0x80;

    static uint32_t u32uSeconds = 0;

    uint32_t* pReg;

    //GPIOCRegs.GPIODATA.bit.PIN7   ^= 1;

    pGPTMRegs = ( ( volatile struct GPTM_REGS* )( 0x40030000 ) );

    //GPTM0Regs.GPTMICR.bit.TATOCINT = 1;

    u32uSeconds += GPTM0_TICK_sec;
    if( u32uSeconds >= GPTM0_HALF_SECOND_sec )
    {
        u32uSeconds -= GPTM0_HALF_SECOND_sec;

        pReg     = ( ( uint32_t* )( 0x4005A200 ) );

        *pReg    = u32Val;

        u32Val ^= 0x80;
    }

    pGPTMRegs->GPTMICR.bit.TATOCINT = 1;
}

/*
 * Periodic Timer Mode (Page 308 TRM)
 */
void gptm0_tmrA_init( void )
{
    volatile struct GPTM_REGS* pRegs;

    psp_utils_enter_privilige_mode();

    pRegs = ( ( volatile struct GPTM_REGS* )( 0x40030000 ) );

    /*
     * 1. Ensure the timer is disabled (the TnEN bit in the GPTMCTL register is cleared) before making any
     *    changes.
     */
    //GPTM0Regs.GPTMCTL.bit.TAEN = ~( TIMER_CTL_TBEN | TIMER_CTL_TAEN );
    pRegs->GPTMCTL.bit.TAEN = ~( TIMER_CTL_TBEN | TIMER_CTL_TAEN );

    /*
     * 2. Write the GPTM Configuration register (GPTMCFG) with a value of 0x0000.0000 (32-bits) OR
     *    0x0000.0004 (16-bits).
     */
    //GPTM0Regs.GPTMCFG.bit.GPTMCFG = GPTM_16BITS_CFG;
    pRegs->GPTMCFG.bit.GPTMCFG = GPTM_16BITS_CFG;

    /*
     * 3. Configure the TnMR field in the GPTM Timer n Mode register (GPTMTnMR)
     * (a) Write a value of 0x1 for one-shot mode.
     * (b) Write a value of 0x2 for periodic mode.
     */
    //GPTM0Regs.GPTMTAMR.bit.TAMR = GPTM_PERIODIC_MODE;
    pRegs->GPTMTAMR.bit.TAMR = GPTM_PERIODIC_MODE;

    /*
     * 4. Optionally configure the TnSNAPS, TnWOT, TnMTE, and TnCDIR bits in the GPTMTnMR register to
     *    select whether to capture the value of the free-running timer at time-out, use an external trigger to start
     *    counting, configure an additional trigger or interrupt, and count up or down.
     */

    /*
     * 5. Load the start value into the GPTM Timer n Interval Load register (GPTMTnILR).
      *                    M3SSCLK = 75  MHz
      * CONFIGURED TIMER FREQUENCY = 0.1 MHz = 100 kHz (10 -sec)
      *        INTERVAL LOAD VALUE = (75  0.1) - 1 = 749.
     */
    //GPTM0Regs.GPTMTAILR.bit.TAILR = 749;
    //GPTM0Regs.GPTMTAPR.bit.TAPSR  = 0;
    pRegs->GPTMTAILR.bit.TAILR = 749;
    pRegs->GPTMTAPR.bit.TAPSR  = 0;

    /*
     * 6. If interrupts are required, set the appropriate bits in the GPTM Interrupt Mask register (GPTMIMR).
     */
    //GPTM0Regs.GPTMICR.bit.TATOCINT  = 1;
    //GPTM0Regs.GPTMIMR.bit.TATOIM    = 1;
    pRegs->GPTMICR.bit.TATOCINT  = 1;
    pRegs->GPTMIMR.bit.TATOIM    = 1;

    NVICRegs.EN0.bit.INT_TIMER0A    = 1;

    /*
     * 7. Set the TnEN bit in the GPTMCTL register to enable the timer and start counting.
     */
    //GPTM0Regs.GPTMCTL.bit.TAEN = 1;
    pRegs->GPTMCTL.bit.TAEN = 1;

    psp_utils_exit_privilige_mode();
}



void gptm_init( void )
{
    gptm0_tmrA_init();
}
