/*
 * File: interupt.c
 */
#include "../../F28M35H52C1M_headers/include/F28M35H52C1_Device.h"

#include "cpu.h"
#include "gptm.h"
#include "interrupt.h"


void ResetISR( void );

static void NmiSR( void );

static void FaultISR( void );

static void IntDefaultHandler( void) ;

extern void _c_int00( void );

//*****************************************************************************
// Linker variable that marks the top of the stack.
//*****************************************************************************
extern unsigned long __STACK_END;

#pragma DATA_ALIGN(g_pfnVectors, 512)
#pragma DATA_SECTION(g_pfnVectors, ".intvecs")

void ( *const g_pfnVectors[] )(void) =
{
    (void (*) (void))((unsigned long)&__STACK_END),                             // 0
    ResetISR,                               // The reset handler
    NmiSR,                                  // The NMI handler
    FaultISR,                               // The hard fault handler
    IntDefaultHandler,                      // The MPU fault handler
    IntDefaultHandler,                      // The bus fault handler
    IntDefaultHandler,                      // The usage fault handler
    0,                                      // Reserved
    0,                                      // Reserved
    0,                                      // Reserved
    0,                                      // Reserved,                            10
    IntDefaultHandler,                      // SVCall handler
    IntDefaultHandler,                      // Debug monitor handler
    0,                                      // Reserved
    IntDefaultHandler,                      // The PendSV handler
    IntDefaultHandler,                      // The SysTick handler
    IntDefaultHandler,                      // GPIO Port A
    IntDefaultHandler,                      // GPIO Port B
    IntDefaultHandler,                      // GPIO Port C
    IntDefaultHandler,                      // GPIO Port D
    IntDefaultHandler,                      // GPIO Port E,                         20
    IntDefaultHandler,                      // UART0 Rx and Tx
    IntDefaultHandler,                      // UART1 Rx and Tx
    IntDefaultHandler,                      // SSI0 Rx and Tx
    IntDefaultHandler,                      // I2C0 Master and Slave
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved,                            30
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Watchdog timer
    Gptm0TAISR,                             // Timer 0 subtimer A
    IntDefaultHandler,                      // Timer 0 subtimer B
    IntDefaultHandler,                      // Timer 1 subtimer A
    IntDefaultHandler,                      // Timer 1 subtimer B
    IntDefaultHandler,                      // Timer 2 subtimer A
    IntDefaultHandler,                      // Timer 2 subtimer B                   40
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // System Control
    IntDefaultHandler,                      // FLASH Control
    IntDefaultHandler,                      // GPIO Port F
    IntDefaultHandler,                      // GPIO Port G
    IntDefaultHandler,                      // GPIO Port H
    IntDefaultHandler,                      // UART2 Rx and Tx
    IntDefaultHandler,                      // SSI1 Rx and Tx                       50
    IntDefaultHandler,                      // Timer 3 subtimer A
    IntDefaultHandler,                      // Timer 3 subtimer B
    IntDefaultHandler,                      // I2C1 Master and Slave
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // EMAC
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // USB0                                 60
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // uDMA Software Transfer
    IntDefaultHandler,                      // uDMA Error
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // External Peripheral Interface
    IntDefaultHandler,                      // GPIO Port J                          70
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // SSI2
    IntDefaultHandler,                      // SSI3
    IntDefaultHandler,                      // UART3
    IntDefaultHandler,                      // UART4
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // CAN0 INT0                            80
    IntDefaultHandler,                      // CAN0 INT1
    IntDefaultHandler,                      // CAN1 INT0
    IntDefaultHandler,                      // CAN1 INT1
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // ADCINT1
    IntDefaultHandler,                      // ADCINT2
    IntDefaultHandler,                      // ADCINT3                              90
    IntDefaultHandler,                      // ADCINT4
    IntDefaultHandler,                      // ADCINT5
    IntDefaultHandler,                      // ADCINT6
    IntDefaultHandler,                      // ADCINT7
    IntDefaultHandler,                      // ADCINT8
    IntDefaultHandler,                      // CTOMIPC1
    IntDefaultHandler,                      // CTOMIPC2
    IntDefaultHandler,                      // CTOMIPC3
    IntDefaultHandler,                      // CTOMIPC4
    IntDefaultHandler,                      // Reserved                             100
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // Reserved
    IntDefaultHandler,                      // RAM Single Error
    IntDefaultHandler,                      // System/USB PLL Out of Lock
    IntDefaultHandler,                      // M3 Flash Single Error
    IntDefaultHandler,                      // Reserved
};

#pragma CODE_SECTION(ResetISR, ".resetisr")
void ResetISR( void )
{
    // Jump to the CCS C Initialization Routine.
    __asm("    .global _c_int00\n"
          "    b.w     _c_int00");
}


static void NmiSR( void )
{
    while( 1 )
    {

    }
}


static void FaultISR( void )
{
    while( 1 )
    {

    }
}


static void IntDefaultHandler( void )
{
    while(1)
    {

    }
}


#pragma DATA_ALIGN(g_pfnRAMVectors, 1024)
#pragma DATA_SECTION(g_pfnRAMVectors, ".vtable")
void (*g_pfnRAMVectors[ ( 136 - 28 ) ] )( void );

void interrupt_init( void )
{
    uint32_t u32MWRAllow;

    uint32_t u32Idx;

    for( u32Idx = 0; u32Idx < ( 136 - 28 ); u32Idx++ )
    {
        g_pfnRAMVectors[u32Idx] = g_pfnVectors[u32Idx];
    }

    u32MWRAllow                     = M3MWRAllowCfgRegs.MWRALLOW.all;

    M3MWRAllowCfgRegs.MWRALLOW.all  = MWR_ALLOW_KEY;

    SCBRegs.VTABLE.all              = ( ( uint32_t )( g_pfnRAMVectors ) );

    M3MWRAllowCfgRegs.MWRALLOW.all  = u32MWRAllow;
}


bool IntMasterEnable( void )
{
    // Enable processor interrupts.
    return( CPUcpsie() );
}
