/*
 * File: psp.c
 */
#include <string.h>

#include "F28M35H52C1_Device.h"

#include "clkcfg.h"
#include "flashctl.h"
#include "interrupt.h"
#include "gpio.h"
#include "gptm.h"
#include "psp_utils.h"
#include "psp.h"

#ifdef _FLASH
// These are defined by the linker (see device linker command file)
extern unsigned long RamfuncsLoadStart;
extern unsigned long RamfuncsRunStart;
extern unsigned long RamfuncsLoadSize;
#endif


static void psp_peripherals_init( void );

static void psp_boot_c28( void );


static void psp_peripherals_init( void )
{
    gpio_init();

    gptm_init();
}


/*
 * Page 578 TRM
 */
static void psp_boot_c28( void )
{
    psp_utils_enter_privilige_mode();

    /*
     * 1. Check if C-Boot ROM is ready to accept IPC commands. If yes,
     *    then proceed to step 2 below, else, wait. CTOMIPCBOOTSTS register
     *    is used by C-Boot ROM to communicate boot status to the master
     *    subsystem.
     */
    while( ( MTOCIPCRegs.CTOMIPCBOOTSTS.all & CBROM_BOOTSTS_CTOM_CONTROL_SYSTEM_READY ) !=
             CBROM_BOOTSTS_CTOM_CONTROL_SYSTEM_READY ) { }

    /*
     * 2. Configure the control subsystem C28x CPU as the owner for
     *    respective GPIO based on boot mode using core select feature
     *    on the GPIO. In other words assign the required GPIO for boot
     *    to the C28x core.
     */

    /*
     * 3. MTOCIPCCOM = MASTER_IPC_MTOC_EXECUTE_BOOTMODE_CMD
     */
    MTOCIPCRegs.MTOCIPCCOM.all = MASTER_IPC_MTOC_EXECUTE_BOOTMODE_CMD;

    /*
     * MTOCIPCBOOTMODE = C-Boot ROM Boot Mode command
     */
    MTOCIPCRegs.MTOCIPCBOOTMODE.all = IPC_MTOC_BOOT_FROM_FLASH_MSG;

    /*
     * 5. MTOCIPCSET = 0x80000001 (set bits 31 and 0 to enable respective
     *    bits in MTOCIPCFLG register) MASTER_IPC_MTOC_EXECUTE_BOOTMODE_CMD
     *    mentioned in step 3 above is one of the IPC commands supported by
     *    C-Boot ROM.
     */
    MTOCIPCRegs.MTOCIPCSET.all |= ( IPC_FLAG32 | IPC_FLAG1 );

    psp_utils_exit_privilige_mode();
}


void psp_init( void )
{
    clkcfg_init();

#ifdef _FLASH
    memcpy( ( ( void* )( &RamfuncsRunStart ) ), ( ( void* )( &RamfuncsLoadStart ) ), ( ( size_t )( &RamfuncsLoadSize ) ) );

    flashctl_init();
#endif

    interrupt_init();

    psp_peripherals_init();

    psp_boot_c28();
}
